#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_label_ar

data_0 = {
    "fictional executed people": "",
    "fictional executed": "",
    "Executed Hungarian collaborators with Nazi Germany": "مجريون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Greek collaborators with Nazi Germany": "يونانيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Iraqi collaborators with Nazi Germany": "عراقيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Jewish collaborators with Nazi Germany": "يهود أعدموا متعاونون مع ألمانيا النازية",
    "Executed Liechtenstein collaborators with Nazi Germany": "ليختنشتانيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Lithuanian collaborators with Nazi Germany": "ليتوانيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Croatian collaborators with Nazi Germany": "كروات أعدموا متعاونون مع ألمانيا النازية",
    "Executed Czech collaborators with Nazi Germany": "تشيكيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Czechoslovak collaborators with Nazi Germany": "تشيكوسلوفاكيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Danish collaborators with Nazi Germany": "دنماركيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Dutch collaborators with Nazi Germany": "هولنديون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Latvian collaborators with Nazi Germany": "لاتفيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed British collaborators with Nazi Germany": "بريطانيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Bulgarian collaborators with Nazi Germany": "بلغاريون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Belarusian collaborators with Nazi Germany": "بيلاروسيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Belgian collaborators with Nazi Germany": "بلجيكيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Albanian collaborators with Nazi Germany": "ألبان أعدموا متعاونون مع ألمانيا النازية",
    "Executed French collaborators with Nazi Germany": "فرنسيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Estonian collaborators with Nazi Germany": "إستونيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed American collaborators with Nazi Germany": "أمريكيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Spanish collaborators with Nazi Germany": "إسبان أعدموا متعاونون مع ألمانيا النازية",
    "Executed Soviet collaborators with Nazi Germany": "سوفيت أعدموا متعاونون مع ألمانيا النازية",
    "Executed Slovak collaborators with Nazi Germany": "سلوفاكيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Serbian collaborators with Nazi Germany": "صرب أعدموا متعاونون مع ألمانيا النازية",
    "Executed Romanian collaborators with Nazi Germany": "رومان أعدموا متعاونون مع ألمانيا النازية",
    "Executed Russian collaborators with Nazi Germany": "روس أعدموا متعاونون مع ألمانيا النازية",
    "Executed Norwegian collaborators with Nazi Germany": "نرويجيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Polish collaborators with Nazi Germany": "بولنديون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Montenegrin collaborators with Nazi Germany": "مونتينيغريون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Ukrainian collaborators with Nazi Germany": "أوكرانيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Yugoslav collaborators with Nazi Germany": "يوغسلافيون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Swiss collaborators with Nazi Germany": "سويسريون أعدموا متعاونون مع ألمانيا النازية",
    "Executed Luxembourgian collaborators with Nazi Germany": "لوكسمبورغيون أعدموا متعاونون مع ألمانيا النازية",
}

data_1 = {
    "argentine people executed": "أرجنتينيون أعدموا",
    "belgian people executed": "بلجيكيون أعدموا",
    "czech people executed": "تشيكيون أعدموا",
    "dutch people executed": "هولنديون أعدموا",
    "Albanian people executed abroad": "ألبان أعدموا في الخارج",
    "Albanian people executed by Nazi Germany": "ألبان أعدموا من قبل ألمانيا النازية",
    "Algerian people executed abroad": "جزائريون أعدموا في الخارج",
    "American people executed abroad": "أمريكيون أعدموا في الخارج",
    "american people executed abroad": "أمريكيون أعدموا في الخارج",
    "American people executed by Nazi Germany": "أمريكيون أعدموا من قبل ألمانيا النازية",
    "American people executed by the Soviet Union": "أمريكيون أعدموا من قبل الاتحاد السوفيتي",
    "American people executed in Canada": "أمريكيون أعدموا في كندا",
    "American people executed in the United Kingdom": "أمريكيون أعدموا في المملكة المتحدة",
    "Anarchists executed by Francoist Spain": "لاسلطويون أعدموا من قبل إسبانيا الفرانكوية",
    "Anarchists executed by the Soviet Union": "لاسلطويون أعدموا من قبل الاتحاد السوفيتي",
    "Argentine people executed abroad": "أرجنتينيون أعدموا في الخارج",
    "Armenian people executed by Nazi Germany": "أرمن أعدموا من قبل ألمانيا النازية",
    "Armenian people executed by the Soviet Union": "أرمن أعدموا من قبل الاتحاد السوفيتي",
    "Australian people executed abroad": "أستراليون أعدموا في الخارج",
    "Austrian people executed abroad": "نمساويون أعدموا في الخارج",
    "Austrian people executed by Nazi Germany": "نمساويون أعدموا من قبل ألمانيا النازية",
    "Austrian people executed by the Soviet Union": "نمساويون أعدموا من قبل الاتحاد السوفيتي",
    "Azerbaijani people executed by the Soviet Union": "أذربيجانيون أعدموا من قبل الاتحاد السوفيتي",
    "Bangladeshi people executed abroad": "بنغلاديشيون أعدموا في الخارج",
    "Belarusian people executed by Nazi Germany": "بيلاروسيون أعدموا من قبل ألمانيا النازية",
    "Belarusian people executed by the Soviet Union": "بيلاروسيون أعدموا من قبل الاتحاد السوفيتي",
    "Belgian people executed by Nazi Germany": "بلجيكيون أعدموا من قبل ألمانيا النازية",
    "Brazilian people executed abroad": "برازيليون أعدموا في الخارج",
    "British people executed abroad": "بريطانيون أعدموا في الخارج",
    "British people executed by Nazi Germany": "بريطانيون أعدموا من قبل ألمانيا النازية",
    "British people executed in the United States": "بريطانيون أعدموا في الولايات المتحدة",
    "Bulgarian people executed abroad": "بلغاريون أعدموا في الخارج",
    "Bulgarian people executed by the Soviet Union": "بلغاريون أعدموا من قبل الاتحاد السوفيتي",
    "Burmese people executed abroad": "بورميون أعدموا في الخارج",
    "Canadian people executed abroad": "كنديون أعدموا في الخارج",
    "Canadian people executed by Nazi Germany": "كنديون أعدموا من قبل ألمانيا النازية",
    "Catholics executed by the Soviet Union": "كاثوليك أعدموا من قبل الاتحاد السوفيتي",
    "Chechen people executed by the Soviet Union": "شيشانيون أعدموا من قبل الاتحاد السوفيتي",
    "Children executed by Nazi Germany": "أطفال أعدموا من قبل ألمانيا النازية",
    "Children executed by the United States": "أطفال أعدموا من قبل الولايات المتحدة",
    "Chinese people executed abroad": "صينيون أعدموا في الخارج",
    "Communists executed by Finland": "شيوعيون أعدموا من قبل فنلندا",
    "Communists executed by Francoist Spain": "شيوعيون أعدموا من قبل إسبانيا الفرانكوية",
    "Communists executed by Iran": "شيوعيون أعدموا من قبل إيران",
    "Communists executed by Nazi Germany": "شيوعيون أعدموا من قبل ألمانيا النازية",
    "Communists executed by the Republic of China": "شيوعيون أعدموا من قبل جمهورية الصين",
    "Communists executed by Vichy France": "شيوعيون أعدموا من قبل فرنسا الفيشية",
    "Croatian people executed by Nazi Germany": "كروات أعدموا من قبل ألمانيا النازية",
    "Cuban people executed abroad": "كوبيون أعدموا في الخارج",
    "Cypriot people executed abroad": "قبرصيون أعدموا في الخارج",
    "Czech people executed by Nazi Germany": "تشيكيون أعدموا من قبل ألمانيا النازية",
    "Danish people executed by Nazi Germany": "دنماركيون أعدموا من قبل ألمانيا النازية",
    "Dutch people executed abroad": "هولنديون أعدموا في الخارج",
    "Dutch people executed by Nazi Germany": "هولنديون أعدموا من قبل ألمانيا النازية",
    "Estonian people executed by Nazi Germany": "إستونيون أعدموا من قبل ألمانيا النازية",
    "Estonian people executed by the Soviet Union": "إستونيون أعدموا من قبل الاتحاد السوفيتي",
}

data_2 = {
    "Executed Afghan people": "أفغان أعدموا",
    "Executed African-American people": "أمريكيون أفارقة أعدموا",
    "executed africanamerican people": "أمريكيون أفارقة أعدموا",
    "Executed Albanian people": "ألبان أعدموا",
    "Executed Algerian people": "جزائريون أعدموا",
    "Executed American people by state or territory": "أمريكيون أعدموا حسب الولاية أو الإقليم",
    "Executed American people": "أمريكيون أعدموا",
    "Executed ancient Greek people": "يونانيون قدماء أعدموا",
    "Executed ancient Macedonian people": "مقدونيون قدماء أعدموا",
    "Executed ancient Roman people": "رومان قدماء أعدموا",
    "Executed Angolan people": "أنغوليون أعدموا",
    "Executed Argentine people": "أرجنتينيون أعدموا",
    "Executed Armenian people": "أرمن أعدموا",
    "executed armenian people": "أرمن أعدموا",
    "Executed Australian people": "أستراليون أعدموا",
    "Executed Austrian people": "نمساويون أعدموا",
    "Executed Azerbaijani people": "أذربيجانيون أعدموا",
    "Executed Bahamian people": "بهاميون أعدموا",
    "Executed Bangladeshi people": "بنغلاديشيون أعدموا",
    "Executed Barbadian people": "بربادوسيون أعدموا",
    "Executed Belarusian people": "بيلاروسيون أعدموا",
    "Executed Belgian people": "بلجيكيون أعدموا",
    "Executed Belizean people": "بليزيون أعدموا",
    "Executed Bermudian people": "برموديون أعدموا",
    "Executed Bolivian people": "بوليفيون أعدموا",
    "Executed Bosnia and Herzegovina people": "بوسنيون أعدموا",
    "Executed Botswana people": "بوتسوانيون أعدموا",
    "Executed Brazilian people": "برازيليون أعدموا",
    "Executed British people": "بريطانيون أعدموا",
    "Executed Bulgarian people": "بلغاريون أعدموا",
    "Executed Burkinabe people": "بوركينابيون أعدموا",
    "Executed Burmese people": "بورميون أعدموا",
    "Executed Byzantine people": "بيزنطيون أعدموا",
    "Executed Cambodian people": "كمبوديون أعدموا",
    "Executed Cameroonian people": "كاميرونيون أعدموا",
    "Executed Canadian people": "كنديون أعدموا",
    "Executed Central African Republic people": "أفارقة أوسطيون أعدموا",
    "Executed Chadian people": "تشاديون أعدموا",
    "Executed Chilean people": "تشيليون أعدموا",
    "Executed Chinese people by period": "صينيون أعدموا حسب الحقبة",
    "Executed Chinese people by province": "صينيون أعدموا حسب المقاطعة",
    "Executed Chinese people": "صينيون أعدموا",
    "Executed Colombian people": "كولومبيون أعدموا",
    "executed colombian people": "كولومبيون أعدموا",
    "Executed Congolese people": "كونغويون أعدموا",
    "Executed Cornish people": "كورنيون أعدموا",
    "Executed Costa Rican people": "كوستاريكيون أعدموا",
    "Executed Croatian people": "كروات أعدموا",
    "Executed Cuban people": "كوبيون أعدموا",
    "Executed Cypriot people": "قبرصيون أعدموا",
    "Executed Czech people": "تشيكيون أعدموا",
    "Executed Czechoslovak people": "تشيكوسلوفاكيون أعدموا",
    "Executed Danish people": "دنماركيون أعدموا",
    "Executed Democratic Republic of the Congo people": "كونغويون ديمقراطيون أعدموا",
    "Executed Dominican Republic people": "دومينيكانيون أعدموا",
    "Executed Dutch people": "هولنديون أعدموا",
    "Executed East German people": "ألمانيون شرقيون أعدموا",
    "Executed Ecuadorian people": "إكوادوريون أعدموا",
    "Executed Egyptian people": "مصريون أعدموا",
    "Executed English people": "إنجليز أعدموا",
    "executed english people": "إنجليز أعدموا",
    "Executed Equatoguinean people": "غينيون استوائيون أعدموا",
    "Executed Estonian people": "إستونيون أعدموا",
    "Executed Ethiopian people": "إثيوبيون أعدموا",
    "Executed Filipino people": "فلبينيون أعدموا",
    "Executed Finnish people": "فنلنديون أعدموا",
    "Executed French people": "فرنسيون أعدموا",
    "executed french": "فرنسيون أعدموا",
    "Executed Gambian people": "غامبيون أعدموا",
    "Executed German people": "ألمان أعدموا",
    "Executed Ghanaian people": "غانيون أعدموا",
    "Executed Greek people": "يونانيون أعدموا",
    "Executed Grenadian people": "غريناديون أعدموا",
    "Executed Guatemalan people": "غواتيماليون أعدموا",
    "Executed Guinean people": "غينيون أعدموا",
    "Executed Haitian people": "هايتيون أعدموا",
    "Executed Honduran people": "هندوراسيون أعدموا",
    "Executed Hong Kong people": "هونغ كونغيون أعدموا",
    "Executed Hungarian people": "مجريون أعدموا",
    "Executed Icelandic people": "آيسلنديون أعدموا",
    "Executed Indian people": "هنود أعدموا",
    "Executed Indonesian people": "إندونيسيون أعدموا",
    "Executed Iranian people": "إيرانيون أعدموا",
    "Executed Iraqi people": "عراقيون أعدموا",
    "Executed Irish people by county": "أيرلنديون أعدموا حسب المقاطعة",
    "Executed Irish people": "أيرلنديون أعدموا",
    "Executed Israeli people": "إسرائيليون أعدموا",
    "Executed Italian people": "إيطاليون أعدموا",
    "Executed Jamaican people": "جامايكيون أعدموا",
    "Executed Japanese people": "يابانيون أعدموا",
    "Executed Jordanian people": "أردنيون أعدموا",
    "Executed Kazakhstani people": "كازاخستانيون أعدموا",
    "Executed Kenyan people": "كينيون أعدموا",
    "Executed Korean people": "كوريون أعدموا",
    "Executed Kosovan people": "كوسوفيون أعدموا",
    "Executed Kurdish people": "أكراد أعدموا",
    "Executed Kyrgyzstani people": "قيرغيزستانيون أعدموا",
    "Executed Laotian people": "لاوسيون أعدموا",
    "Executed Latvian people": "لاتفيون أعدموا",
    "Executed Lebanese people": "لبنانيون أعدموا",
    "Executed Liberian people": "ليبيريون أعدموا",
    "Executed Liechtenstein people": "ليختنشتانيون أعدموا",
    "Executed Libyan people": "ليبيون أعدموا",
    "Executed Luxembourgian people": "لوكسمبورغيون أعدموا",
    "Executed Macedonian people": "مقدونيون أعدموا",
    "Executed Malagasy people": "مدغشقريون أعدموا",
    "Executed Malawian people": "ملاويون أعدموا",
    "Executed Lithuanian people": "ليتوانيون أعدموا",
    "Executed Malaysian people": "ماليزيون أعدموا",
    "Executed Malian people": "ماليون أعدموا",
    "Executed Maltese people": "مالطيون أعدموا",
    "Executed Manx people": "مانكسيون أعدموا",
    "Executed Mauritian people": "موريشيوسيون أعدموا",
    "Executed Mexican people": "مكسيكيون أعدموا",
    "Executed Moldovan people": "مولدوفيون أعدموا",
    "Executed Mongolian people": "منغوليون أعدموا",
    "Executed Montenegrin people": "مونتينيغريون أعدموا",
    "executed montenegrin people": "مونتينيغريون أعدموا",
    "Executed Moroccan people": "مغاربة أعدموا",
    "Executed Mozambican people": "موزمبيقيون أعدموا",
    "Executed Native American people": "أمريكيون أصليون أعدموا",
    "Executed Nazis by location": "نازيون أعدموا حسب الموقع",
    "Executed Nazis": "نازيون أعدموا",
    "Executed Nepalese people": "نيباليون أعدموا",
    "Executed New Zealand people": "نيوزيلنديون أعدموا",
    "Executed Nicaraguan people": "نيكاراغويون أعدموا",
    "Executed Nigerian people": "نيجيريون أعدموا",
    "executed nigerien people": "نيجريون أعدموا",
    "Executed Nigerien people": "نيجريون أعدموا",
    "Executed North Korean people": "كوريون شماليون أعدموا",
    "Executed Norwegian people": "نرويجيون أعدموا",
    "executed pakistani people": "باكستانيون أعدموا",
    "Executed Pakistani people": "باكستانيون أعدموا",
    "Executed Palestinian people": "فلسطينيون أعدموا",
    "Executed Panamanian people": "بنميون أعدموا",
    "Executed Paraguayan people": "بارغوايانيون أعدموا",
    "Executed Portuguese people": "برتغاليون أعدموا",
    "Executed Polish people": "بولنديون أعدموا",
    "Executed Peruvian people": "بيرويون أعدموا",
    "Executed Romanian people": "رومان أعدموا",
    "Executed Russian people": "روس أعدموا",
    "Executed Rwandan people": "روانديون أعدموا",
    "Executed Salvadoran people": "سلفادوريون أعدموا",
    "Executed Puerto Rican people": "بورتوريكيون أعدموا",
    "Executed Republic of the Congo people": "كونغويون أعدموا",
    "Executed Saudi Arabian people": "سعوديون أعدموا",
    "Executed Scottish people": "إسكتلنديون أعدموا",
    "Executed Senegalese people": "سنغاليون أعدموا",
    "Executed Serbian people": "صرب أعدموا",
    "executed serbian": "صرب أعدموا",
    "Executed Sierra Leonean people": "سيراليونيون أعدموا",
    "Executed Singaporean people": "سنغافوريون أعدموا",
    "Executed Slovak people": "سلوفاكيون أعدموا",
    "Executed Slovenian people": "سلوفينيون أعدموا",
    "Executed Somalian people": "صوماليون أعدموا",
    "Executed South African people": "جنوب إفريقيون أعدموا",
    "executed south african people": "جنوب إفريقيون أعدموا",
    "Executed South Korean people": "كوريون جنوبيون أعدموا",
    "Executed Soviet people from Armenia": "سوفيت أعدموا من أرمينيا",
    "Executed Soviet people from Azerbaijan": "سوفيت أعدموا من أذربيجان",
    "Executed Soviet people from Belarus": "سوفيت أعدموا من روسيا البيضاء",
    "Executed Soviet people from Estonia": "سوفيت أعدموا من إستونيا",
    "Executed Soviet people from Georgia (country)": "سوفيت أعدموا من جورجيا",
    "Executed Soviet people from Kazakhstan": "سوفيت أعدموا من كازاخستان",
    "Executed Soviet people from Kyrgyzstan": "سوفيت أعدموا من قيرغيزستان",
    "Executed Soviet people from Latvia": "سوفيت أعدموا من لاتفيا",
    "Executed Soviet people from Lithuania": "سوفيت أعدموا من ليتوانيا",
    "Executed Soviet people from Moldova": "سوفيت أعدموا من مولدوفا",
    "Executed Soviet people from Russia": "سوفيت أعدموا من روسيا",
    "Executed Soviet people from Tajikistan": "سوفيت أعدموا من طاجيكستان",
    "Executed Soviet people from Ukraine": "سوفيت أعدموا من أوكرانيا",
    "Executed Soviet people from Uzbekistan": "سوفيت أعدموا من أوزبكستان",
    "Executed Soviet people": "سوفيت أعدموا",
    "Executed Spanish people": "إسبان أعدموا",
    "Executed Sri Lankan people": "سريلانكيون أعدموا",
    "Executed Sudanese people": "سودانيون أعدموا",
    "Executed Surinamese people": "سوريناميون أعدموا",
    "Executed Swedish people": "سويديون أعدموا",
    "Executed Swiss people": "سويسريون أعدموا",
    "Executed Syrian people": "سوريون أعدموا",
    "Executed Taiwanese people": "تايوانيون أعدموا",
    "executed tajikistani people": "طاجيك أعدموا",
    "Executed Tajikistani people": "طاجيك أعدموا",
    "Executed Tanzanian people": "تنزانيون أعدموا",
    "Executed Thai people": "تايلنديون أعدموا",
    "Executed Trinidad and Tobago people": "ترنيداديون أعدموا",
    "Executed Tunisian people": "تونسيون أعدموا",
    "Executed Turkish people": "أتراك أعدموا",
    "Executed Turkmenistan people": "تركمانيون أعدموا",
    "Executed Ugandan people": "أوغنديون أعدموا",
    "Executed Ukrainian people": "أوكرانيون أعدموا",
    "executed ukrainian people": "أوكرانيون أعدموا",
    "executed ukrainian": "أوكرانيون أعدموا",
    "Executed Uzbekistani people": "أوزبكستانيون أعدموا",
    "Executed Venezuelan people": "فنزويليون أعدموا",
    "Executed Vietnamese people": "فيتناميون أعدموا",
    "Executed Welsh people": "ويلزيون أعدموا",
    "Executed Yemeni people": "يمنيون أعدموا",
    "Executed Yugoslav people": "يوغسلافيون أعدموا",
    "Executed Albanian women": "ألبانيات أعدمن",
    "Executed American women": "أمريكيات أعدمن",
    "Executed ancient Roman women": "رومانيات قديمات أعدمن",
    "Executed Argentine women": "أرجنتينيات أعدمن",
    "Executed Australian women": "أستراليات أعدمن",
    "Executed Austrian women": "نمساويات أعدمن",
    "Executed Azerbaijani women": "أذربيجانيات أعدمن",
    "Executed Belgian women": "بلجيكيات أعدمن",
    "Executed Bolivian women": "بوليفيات أعدمن",
    "Executed British women": "بريطانيات أعدمن",
    "Executed Cambodian women": "كمبوديات أعدمن",
    "Executed Canadian women": "كنديات أعدمن",
    "Executed Chinese women": "صينيات أعدمن",
    "Executed Colombian women": "كولومبيات أعدمن",
    "Executed Cypriot women": "قبرصيات أعدمن",
    "Executed Czech women": "تشيكيات أعدمن",
    "Executed Czechoslovak women": "تشيكوسلوفاكيات أعدمن",
    "Executed Danish women": "دنماركيات أعدمن",
    "Executed Dutch women": "هولنديات أعدمن",
    "Executed English women": "إنجليزيات أعدمن",
    "Executed Filipino women": "فلبينيات أعدمن",
    "Executed Finnish women": "فنلنديات أعدمن",
    "Executed French women": "فرنسيات أعدمن",
    "Executed German women": "ألمانيات أعدمن",
    "Executed Greek women": "يونانيات أعدمن",
    "Executed Indian women": "هنديات أعدمن",
    "Executed Iranian women": "إيرانيات أعدمن",
    "Executed Iraqi women": "عراقيات أعدمن",
    "Executed Irish women": "أيرلنديات أعدمن",
    "Executed Italian women": "إيطاليات أعدمن",
    "Executed Japanese women": "يابانيات أعدمن",
    "Executed Korean women": "كوريات أعدمن",
    "Executed Liechtenstein women": "ليختنشتانيات أعدمن",
    "Executed Malaysian women": "ماليزيات أعدمن",
    "Executed Mexican women": "مكسيكيات أعدمن",
    "Executed New Zealand women": "نيوزيلنديات أعدمن",
    "Executed Norwegian women": "نرويجيات أعدمن",
    "Executed Peruvian women": "بيرويات أعدمن",
    "Executed Polish women": "بولنديات أعدمن",
    "Executed Portuguese women": "برتغاليات أعدمن",
    "Executed Romanian women": "رومانيات أعدمن",
    "Executed Russian women": "روسيات أعدمن",
    "Executed Saudi Arabian women": "سعوديات أعدمن",
    "Executed Scottish women": "إسكتلنديات أعدمن",
    "Executed Singaporean women": "سنغافوريات أعدمن",
    "Executed South African women": "جنوب إفريقيات أعدمن",
    "Executed Soviet women": "سوفيتيات أعدمن",
    "Executed Spanish women": "إسبانيات أعدمن",
    "Executed Sri Lankan women": "سريلانكيات أعدمن",
    "Executed Swedish women": "سويديات أعدمن",
    "Executed Swiss women": "سويسريات أعدمن",
    "Executed Thai women": "تايلنديات أعدمن",
    "Executed Ukrainian women": "أوكرانيات أعدمن",
    "Executed Welsh women": "ويلزيات أعدمن",
}

data_3 = {
    "French people executed by guillotine during the French Revolution": "فرنسيون أعدموا بالمقصلة خلال الثورة الفرنسية",
    "german people executed": "ألمان أعدموا",
    "Nazis executed by firing squad": "نازيون أعدموا رميا بالرصاص",
    "Nazis executed by guillotine": "نازيون أعدموا بالمقصلة",
    "Military personnel executed during the Iranian Revolution": "أفراد عسكريون أعدموا خلال الثورة الإيرانية",
    "Military personnel executed during World War I": "أفراد عسكريون أعدموا خلال الحرب العالمية الأولى",
    "Politicians executed during the Iranian Revolution": "سياسيون أعدموا خلال الثورة الإيرانية",
    "Filipino people executed abroad": "فلبينيون أعدموا في الخارج",
    "Finnish people executed abroad": "فنلنديون أعدموا في الخارج",
    "Finnish people executed by the Soviet Union": "فنلنديون أعدموا من قبل الاتحاد السوفيتي",
    "French people executed abroad": "فرنسيون أعدموا في الخارج",
    "French people executed by Nazi Germany": "فرنسيون أعدموا من قبل ألمانيا النازية",
    "German people executed abroad": "ألمان أعدموا في الخارج",
    "German people executed by Nazi Germany": "ألمان أعدموا من قبل ألمانيا النازية",
    "German people executed by the Soviet Union": "ألمان أعدموا من قبل الاتحاد السوفيتي",
    "German people executed in the United Kingdom": "ألمان أعدموا في المملكة المتحدة",
    "German people executed in the United States": "ألمان أعدموا في الولايات المتحدة",
    "Greek people executed by Nazi Germany": "يونانيون أعدموا من قبل ألمانيا النازية",
    "Greek people executed by the Soviet Union": "يونانيون أعدموا من قبل الاتحاد السوفيتي",
    "Hungarian people executed abroad": "مجريون أعدموا في الخارج",
    "Hungarian people executed by Nazi Germany": "مجريون أعدموا من قبل ألمانيا النازية",
    "Hungarian people executed by the Soviet Union": "مجريون أعدموا من قبل الاتحاد السوفيتي",
    "Indian people executed abroad": "هنود أعدموا في الخارج",
    "Indian people executed by the Soviet Union": "هنود أعدموا من قبل الاتحاد السوفيتي",
    "Indonesian people executed abroad": "إندونيسيون أعدموا في الخارج",
    "Iranian people executed abroad": "إيرانيون أعدموا في الخارج",
    "Iraqi people executed abroad": "عراقيون أعدموا في الخارج",
    "Irish people executed abroad": "أيرلنديون أعدموا في الخارج",
    "Israeli people executed abroad": "إسرائيليون أعدموا في الخارج",
    "Italian people executed abroad": "إيطاليون أعدموا في الخارج",
    "Italian people executed by Nazi Germany": "إيطاليون أعدموا من قبل ألمانيا النازية",
    "Italian people executed in the United States": "إيطاليون أعدموا في الولايات المتحدة",
    "Japanese people executed abroad": "يابانيون أعدموا في الخارج",
    "Jews executed by Nazi Germany": "يهود أعدموا من قبل ألمانيا النازية",
    "Jews executed by Soviet Union": "يهود أعدموا من قبل الاتحاد السوفيتي",
    "Jews executed by the Soviet Union": "يهود أعدموا من قبل الاتحاد السوفيتي",
    "Kazakhstani people executed by the Soviet Union": "كازاخستانيون أعدموا من قبل الاتحاد السوفيتي",
    "Laotian people executed abroad": "لاوسيون أعدموا في الخارج",
    "Latvian people executed by Nazi Germany": "لاتفيون أعدموا من قبل ألمانيا النازية",
    "Latvian people executed by the Soviet Union": "لاتفيون أعدموا من قبل الاتحاد السوفيتي",
    "Lists of people executed in Texas": "قوائم أشخاص أعدموا في تكساس",
    "Lists of people executed in the United States": "قوائم أشخاص أعدموا في الولايات المتحدة",
    "Lithuanian people executed by Nazi Germany": "ليتوانيون أعدموا من قبل ألمانيا النازية",
    "Lithuanian people executed by the Soviet Union": "ليتوانيون أعدموا من قبل الاتحاد السوفيتي",
    "Lithuanian resistance members executed by the Soviet Union": "أعضاء مقاومة ليتوانيون أعدموا من قبل الاتحاد السوفيتي",
    "Malaysian people executed abroad": "ماليزيون أعدموا في الخارج",
    "Malian people executed by Nazi Germany": "ماليون أعدموا من قبل ألمانيا النازية",
    "Members of the Communist Party of the Soviet Union executed by the Soviet Union": "أعضاء الحزب الشيوعي في الاتحاد السوفيتي أعدموا من قبل الاتحاد السوفيتي",
    "Mexican people executed abroad": "مكسيكيون أعدموا في الخارج",
    "Mexican people executed in the United States": "مكسيكيون أعدموا في الولايات المتحدة",
    "Moldovan people executed by the Soviet Union": "مولدوفيون أعدموا من قبل الاتحاد السوفيتي",
    "Mongolian people executed abroad": "منغوليون أعدموا في الخارج",
    "Montenegrin people executed abroad": "مونتينيغريون أعدموا في الخارج",
    "Nazis executed by Austria by hanging": "نازيون أعدموا من قبل النمسا بالشنق",
    "Nazis executed by Czechoslovakia by firing squad": "نازيون أعدموا من قبل تشيكوسلوفاكيا رميا بالرصاص",
    "Nazis executed by Czechoslovakia by hanging": "نازيون أعدموا من قبل تشيكوسلوفاكيا بالشنق",
    "Nazis executed by East Germany by firearm": "نازيون أعدموا من قبل ألمانيا الشرقية بسلاح ناري",
    "Nazis executed by East Germany by guillotine": "نازيون أعدموا من قبل ألمانيا الشرقية بالمقصلة",
    "Nazis executed by France by firing squad": "نازيون أعدموا من قبل فرنسا رميا بالرصاص",
    "Nazis executed by France": "نازيون أعدموا من قبل فرنسا",
    "Nazis executed by Nazi Germany by firearm": "نازيون أعدموا من قبل ألمانيا النازية بسلاح ناري",
    "Nazis executed by Nazi Germany by firing squad": "نازيون أعدموا من قبل ألمانيا النازية رميا بالرصاص",
    "Nazis executed by Nazi Germany by hanging": "نازيون أعدموا من قبل ألمانيا النازية بالشنق",
    "Nazis executed by Nazi Germany": "نازيون أعدموا من قبل ألمانيا النازية",
    "Nazis executed by Poland by hanging": "نازيون أعدموا من قبل بولندا بالشنق",
    "Nazis executed by the British military by firing squad": "نازيون أعدموا من قبل الجيش البريطاني رميا بالرصاص",
    "Nazis executed by the British military by hanging": "نازيون أعدموا من قبل الجيش البريطاني بالشنق",
    "Nazis executed by the Soviet Union by firearm": "نازيون أعدموا من قبل الاتحاد السوفيتي بسلاح ناري",
    "Nazis executed by the Soviet Union by firing squad": "نازيون أعدموا من قبل الاتحاد السوفيتي رميا بالرصاص",
    "Nazis executed by the Soviet Union by hanging": "نازيون أعدموا من قبل الاتحاد السوفيتي بالشنق",
    "Nazis executed by the Soviet Union": "نازيون أعدموا من قبل الاتحاد السوفيتي",
    "Nazis executed by the United Kingdom by hanging": "نازيون أعدموا من قبل المملكة المتحدة بالشنق",
    "Nazis executed by the United Kingdom": "نازيون أعدموا من قبل المملكة المتحدة",
    "Nazis executed by Yugoslavia by firing squad": "نازيون أعدموا من قبل يوغسلافيا رميا بالرصاص",
    "Nazis executed by Yugoslavia by hanging": "نازيون أعدموا من قبل يوغسلافيا بالشنق",
    "Nazis executed in Albania": "نازيون أعدموا في ألبانيا",
    "Nazis executed in Austria": "نازيون أعدموا في النمسا",
    "Nazis executed in Czechoslovakia": "نازيون أعدموا في تشيكوسلوفاكيا",
    "Nazis executed in East Germany": "نازيون أعدموا في ألمانيا الشرقية",
    "Nazis executed in France": "نازيون أعدموا في فرنسا",
    "Nazis executed in Greece": "نازيون أعدموا في اليونان",
    "Nazis executed in Norway": "نازيون أعدموا في النرويج",
    "Nazis executed in Poland": "نازيون أعدموا في بولندا",
    "Nazis executed in Yugoslavia": "نازيون أعدموا في يوغسلافيا",
    "New Zealand people executed abroad": "نيوزيلنديون أعدموا في الخارج",
    "New Zealand people executed by Nazi Germany": "نيوزيلنديون أعدموا من قبل ألمانيا النازية",
    "Nigerian people executed abroad": "نيجيريون أعدموا في الخارج",
    "Norwegian people executed abroad": "نرويجيون أعدموا في الخارج",
    "Norwegian people executed by Nazi Germany": "نرويجيون أعدموا من قبل ألمانيا النازية",
    "Pakistani people executed abroad": "باكستانيون أعدموا في الخارج",
    "Palestinian people executed abroad": "فلسطينيون أعدموا في الخارج",
    "People executed by Afghanistan by firearm": "أشخاص أعدموا من قبل أفغانستان بسلاح ناري",
    "People executed by Afghanistan by firing squad": "أشخاص أعدموا من قبل أفغانستان رميا بالرصاص",
    "People executed by Afghanistan by hanging": "أشخاص أعدموا من قبل أفغانستان بالشنق",
    "People executed by Afghanistan": "أشخاص أعدموا من قبل أفغانستان",
    "People executed by Alabama by hanging": "أشخاص أعدموا من قبل ألاباما بالشنق",
    "People executed by Alabama": "أشخاص أعدموا من قبل ألاباما",
    "People executed by Albania by firing squad": "أشخاص أعدموا من قبل ألبانيا رميا بالرصاص",
    "People executed by Albania by hanging": "أشخاص أعدموا من قبل ألبانيا بالشنق",
    "People executed by Albania": "أشخاص أعدموا من قبل ألبانيا",
    "People executed by Alexander the Great": "أشخاص أعدموا من قبل الإسكندر الأكبر",
    "People executed by ancient Athens": "أشخاص أعدموا من قبل أثينا القديمة",
    "People executed by ancient Egypt": "أشخاص أعدموا من قبل مصر القديمة",
    "People executed by ancient Rome": "أشخاص أعدموا من قبل روما القديمة",
    "People executed by Angola by firing squad": "أشخاص أعدموا من قبل أنغولا رميا بالرصاص",
    "People executed by Angola": "أشخاص أعدموا من قبل أنغولا",
    "People executed by Argentina by firearm": "أشخاص أعدموا من قبل الأرجنتين بسلاح ناري",
    "People executed by Argentina by firing squad": "أشخاص أعدموا من قبل الأرجنتين رميا بالرصاص",
    "People executed by Argentina": "أشخاص أعدموا من قبل الأرجنتين",
    "People executed by Arizona by hanging": "أشخاص أعدموا من قبل أريزونا بالشنق",
    "People executed by Arizona": "أشخاص أعدموا من قبل أريزونا",
    "People executed by Arkansas by hanging": "أشخاص أعدموا من قبل أركنساس بالشنق",
    "People executed by Arkansas": "أشخاص أعدموا من قبل أركنساس",
    "People executed by Australia by hanging": "أشخاص أعدموا من قبل أستراليا بالشنق",
    "People executed by Australia": "أشخاص أعدموا من قبل أستراليا",
    "People executed by Austria by burning": "أشخاص أعدموا من قبل النمسا بالحرق",
    "People executed by Austria by decapitation": "أشخاص أعدموا من قبل النمسا بقطع الرأس",
    "People executed by Austria by firing squad": "أشخاص أعدموا من قبل النمسا رميا بالرصاص",
    "People executed by Austria by hanging": "أشخاص أعدموا من قبل النمسا بالشنق",
    "People executed by Austria": "أشخاص أعدموا من قبل النمسا",
    "People executed by Austria-Hungary": "أشخاص أعدموا من قبل الإمبراطورية النمساوية المجرية",
    "People executed by Bangladesh by hanging": "أشخاص أعدموا من قبل بنغلاديش بالشنق",
    "People executed by Bangladesh": "أشخاص أعدموا من قبل بنغلاديش",
    "People executed by Bavaria": "أشخاص أعدموا من قبل بافاريا",
    "People executed by Belarus by firearm": "أشخاص أعدموا من قبل روسيا البيضاء بسلاح ناري",
    "People executed by Belarus": "أشخاص أعدموا من قبل روسيا البيضاء",
    "People executed by Belgium by decapitation": "أشخاص أعدموا من قبل بلجيكا بقطع الرأس",
    "People executed by Belgium by firing squad": "أشخاص أعدموا من قبل بلجيكا رميا بالرصاص",
    "People executed by Belgium by guillotine": "أشخاص أعدموا من قبل بلجيكا بالمقصلة",
    "People executed by Belgium by hanging": "أشخاص أعدموا من قبل بلجيكا بالشنق",
    "People executed by Belgium": "أشخاص أعدموا من قبل بلجيكا",
    "People executed by Belize by hanging": "أشخاص أعدموا من قبل بليز بالشنق",
    "People executed by Belize": "أشخاص أعدموا من قبل بليز",
    "People executed by Bermuda by hanging": "أشخاص أعدموا من قبل برمودا بالشنق",
    "People executed by Bermuda": "أشخاص أعدموا من قبل برمودا",
    "People executed by Bolivia by firing squad": "أشخاص أعدموا من قبل بوليفيا رميا بالرصاص",
    "People executed by Bolivia": "أشخاص أعدموا من قبل بوليفيا",
    "People executed by Botswana by hanging": "أشخاص أعدموا من قبل بوتسوانا بالشنق",
    "People executed by Botswana": "أشخاص أعدموا من قبل بوتسوانا",
    "People executed by Brazil by firing squad": "أشخاص أعدموا من قبل البرازيل رميا بالرصاص",
    "People executed by Brazil by hanging": "أشخاص أعدموا من قبل البرازيل بالشنق",
    "People executed by Brazil": "أشخاص أعدموا من قبل البرازيل",
    "People executed by British Ceylon": "أشخاص أعدموا من قبل سيلان البريطانية",
    "People executed by British Cyprus by hanging": "أشخاص أعدموا من قبل قبرص البريطانية بالشنق",
    "People executed by British Cyprus": "أشخاص أعدموا من قبل قبرص البريطانية",
    "People executed by British Hong Kong by hanging": "أشخاص أعدموا من قبل هونغ كونغ البريطانية بالشنق",
    "People executed by British Hong Kong": "أشخاص أعدموا من قبل هونغ كونغ البريطانية",
    "People executed by British India by hanging": "أشخاص أعدموا من قبل الراج البريطاني بالشنق",
    "People executed by British India": "أشخاص أعدموا من قبل الراج البريطاني",
    "People executed by British Malaya by hanging": "أشخاص أعدموا من قبل ملايا البريطانية بالشنق",
    "People executed by British Malaya": "أشخاص أعدموا من قبل ملايا البريطانية",
    "People executed by Bulgaria by decapitation": "أشخاص أعدموا من قبل بلغاريا بقطع الرأس",
    "People executed by Bulgaria by firearm": "أشخاص أعدموا من قبل بلغاريا بسلاح ناري",
    "People executed by Bulgaria by firing squad": "أشخاص أعدموا من قبل بلغاريا رميا بالرصاص",
    "People executed by Bulgaria by hanging": "أشخاص أعدموا من قبل بلغاريا بالشنق",
    "People executed by Bulgaria": "أشخاص أعدموا من قبل بلغاريا",
    "People executed by Burkina Faso by firearm": "أشخاص أعدموا من قبل بوركينا فاسو بسلاح ناري",
    "People executed by Burkina Faso by firing squad": "أشخاص أعدموا من قبل بوركينا فاسو رميا بالرصاص",
    "People executed by Burkina Faso": "أشخاص أعدموا من قبل بوركينا فاسو",
    "People executed by California by hanging": "أشخاص أعدموا من قبل كاليفورنيا بالشنق",
    "People executed by California": "أشخاص أعدموا من قبل كاليفورنيا",
    "People executed by Cambodia by firearm": "أشخاص أعدموا من قبل كمبوديا بسلاح ناري",
    "People executed by Cambodia by firing squad": "أشخاص أعدموا من قبل كمبوديا رميا بالرصاص",
    "People executed by Cambodia": "أشخاص أعدموا من قبل كمبوديا",
    "People executed by Cameroon by firearm": "أشخاص أعدموا من قبل الكاميرون بسلاح ناري",
    "People executed by Cameroon by firing squad": "أشخاص أعدموا من قبل الكاميرون رميا بالرصاص",
    "People executed by Cameroon": "أشخاص أعدموا من قبل الكاميرون",
    "People executed by Canada by firing squad": "أشخاص أعدموا من قبل كندا رميا بالرصاص",
    "People executed by Canada by hanging": "أشخاص أعدموا من قبل كندا بالشنق",
    "People executed by Canada": "أشخاص أعدموا من قبل كندا",
    "People executed by Cao Wei": "أشخاص أعدموا من قبل مملكة واي",
    "People executed by Chad": "أشخاص أعدموا من قبل تشاد",
    "People executed by Chile by firearm": "أشخاص أعدموا من قبل تشيلي بسلاح ناري",
    "People executed by Chile by firing squad": "أشخاص أعدموا من قبل تشيلي رميا بالرصاص",
    "People executed by Chile by hanging": "أشخاص أعدموا من قبل تشيلي بالشنق",
    "People executed by Chile": "أشخاص أعدموا من قبل تشيلي",
    "People executed by China by burning": "أشخاص أعدموا من قبل الصين بالحرق",
    "People executed by China by decapitation": "أشخاص أعدموا من قبل الصين بقطع الرأس",
    "People executed by China by firearm": "أشخاص أعدموا من قبل الصين بسلاح ناري",
    "People executed by China by firing squad": "أشخاص أعدموا من قبل الصين رميا بالرصاص",
    "People executed by China by hanging": "أشخاص أعدموا من قبل الصين بالشنق",
    "People executed by China": "أشخاص أعدموا من قبل الصين",
    "People executed by Colombia by firearm": "أشخاص أعدموا من قبل كولومبيا بسلاح ناري",
    "People executed by Colombia by firing squad": "أشخاص أعدموا من قبل كولومبيا رميا بالرصاص",
    "People executed by Colombia by hanging": "أشخاص أعدموا من قبل كولومبيا بالشنق",
    "People executed by Colombia": "أشخاص أعدموا من قبل كولومبيا",
    "People executed by Colorado by hanging": "أشخاص أعدموا من قبل كولورادو بالشنق",
    "People executed by Colorado": "أشخاص أعدموا من قبل كولورادو",
    "People executed by Connecticut by hanging": "أشخاص أعدموا من قبل كونيتيكت بالشنق",
    "People executed by Connecticut": "أشخاص أعدموا من قبل كونيتيكت",
    "People executed by Costa Rica by firing squad": "أشخاص أعدموا من قبل كوستاريكا رميا بالرصاص",
    "People executed by Costa Rica": "أشخاص أعدموا من قبل كوستاريكا",
    "People executed by Cuba by firearm": "أشخاص أعدموا من قبل كوبا بسلاح ناري",
    "People executed by Cuba by firing squad": "أشخاص أعدموا من قبل كوبا رميا بالرصاص",
    "People executed by Cuba": "أشخاص أعدموا من قبل كوبا",
    "People executed by Cyprus by hanging": "أشخاص أعدموا من قبل قبرص بالشنق",
    "People executed by Cyprus": "أشخاص أعدموا من قبل قبرص",
    "People executed by Czechoslovakia by firing squad": "أشخاص أعدموا من قبل تشيكوسلوفاكيا رميا بالرصاص",
    "People executed by Czechoslovakia by hanging": "أشخاص أعدموا من قبل تشيكوسلوفاكيا بالشنق",
    "People executed by Czechoslovakia": "أشخاص أعدموا من قبل تشيكوسلوفاكيا",
    "People executed by Delaware by hanging": "أشخاص أعدموا من قبل ديلاوير بالشنق",
    "People executed by Delaware": "أشخاص أعدموا من قبل ديلاوير",
    "People executed by Denmark by burning": "أشخاص أعدموا من قبل الدنمارك بالحرق",
    "People executed by Denmark by decapitation": "أشخاص أعدموا من قبل الدنمارك بقطع الرأس",
    "People executed by Denmark by firing squad": "أشخاص أعدموا من قبل الدنمارك رميا بالرصاص",
    "People executed by Denmark by hanging": "أشخاص أعدموا من قبل الدنمارك بالشنق",
    "People executed by Denmark": "أشخاص أعدموا من قبل الدنمارك",
    "People executed by Dominica by hanging": "أشخاص أعدموا من قبل دومينيكا بالشنق",
    "People executed by Dominica": "أشخاص أعدموا من قبل دومينيكا",
    "People executed by Duchy of Modena and Reggio": "أشخاص أعدموا من قبل دوقية مودينا وريدجو",
    "People executed by East Germany by firearm": "أشخاص أعدموا من قبل ألمانيا الشرقية بسلاح ناري",
    "People executed by East Germany by guillotine": "أشخاص أعدموا من قبل ألمانيا الشرقية بالمقصلة",
    "People executed by East Germany": "أشخاص أعدموا من قبل ألمانيا الشرقية",
    "People executed by Eastern Wu": "أشخاص أعدموا من قبل مملكة وو",
    "People executed by Ecuador": "أشخاص أعدموا من قبل الإكوادور",
    "People executed by Egypt by burning": "أشخاص أعدموا من قبل مصر بالحرق",
    "People executed by Egypt by firing squad": "أشخاص أعدموا من قبل مصر رميا بالرصاص",
    "People executed by Egypt by hanging": "أشخاص أعدموا من قبل مصر بالشنق",
    "People executed by Egypt": "أشخاص أعدموا من قبل مصر",
    "People executed by El Salvador by firing squad": "أشخاص أعدموا من قبل السلفادور رميا بالرصاص",
    "People executed by El Salvador by hanging": "أشخاص أعدموا من قبل السلفادور بالشنق",
    "People executed by El Salvador": "أشخاص أعدموا من قبل السلفادور",
    "People executed by England and Wales by burning": "أشخاص أعدموا من قبل إنجلترا وويلز بالحرق",
    "People executed by England and Wales by hanging": "أشخاص أعدموا من قبل إنجلترا وويلز بالشنق",
    "People executed by England and Wales": "أشخاص أعدموا من قبل إنجلترا وويلز",
    "People executed by England by burning": "أشخاص أعدموا من قبل إنجلترا بالحرق",
    "People executed by England by decapitation": "أشخاص أعدموا من قبل إنجلترا بقطع الرأس",
    "People executed by England by firearm": "أشخاص أعدموا من قبل إنجلترا بسلاح ناري",
    "People executed by England by firing squad": "أشخاص أعدموا من قبل إنجلترا رميا بالرصاص",
    "People executed by England by hanging": "أشخاص أعدموا من قبل إنجلترا بالشنق",
    "People executed by England": "أشخاص أعدموا من قبل إنجلترا",
    "People executed by Equatorial Guinea by firing squad": "أشخاص أعدموا من قبل غينيا الاستوائية رميا بالرصاص",
    "People executed by Equatorial Guinea": "أشخاص أعدموا من قبل غينيا الاستوائية",
    "People executed by Estonia by firing squad": "أشخاص أعدموا من قبل إستونيا رميا بالرصاص",
    "People executed by Estonia": "أشخاص أعدموا من قبل إستونيا",
    "People executed by Ethiopia by decapitation": "أشخاص أعدموا من قبل إثيوبيا بقطع الرأس",
    "People executed by Ethiopia by firing squad": "أشخاص أعدموا من قبل إثيوبيا رميا بالرصاص",
    "People executed by Ethiopia by hanging": "أشخاص أعدموا من قبل إثيوبيا بالشنق",
    "People executed by Ethiopia": "أشخاص أعدموا من قبل إثيوبيا",
    "People executed by Finland by decapitation": "أشخاص أعدموا من قبل فنلندا بقطع الرأس",
    "People executed by Finland by firearm": "أشخاص أعدموا من قبل فنلندا بسلاح ناري",
    "People executed by Finland by firing squad": "أشخاص أعدموا من قبل فنلندا رميا بالرصاص",
    "People executed by Finland by hanging": "أشخاص أعدموا من قبل فنلندا بالشنق",
    "People executed by Finland": "أشخاص أعدموا من قبل فنلندا",
    "People executed by Florence": "أشخاص أعدموا من قبل فلورنسا",
    "People executed by Florida by hanging": "أشخاص أعدموا من قبل فلوريدا بالشنق",
    "People executed by Florida": "أشخاص أعدموا من قبل فلوريدا",
    "People executed by France by burning": "أشخاص أعدموا من قبل فرنسا بالحرق",
    "People executed by France by decapitation": "أشخاص أعدموا من قبل فرنسا بقطع الرأس",
    "People executed by France by firearm": "أشخاص أعدموا من قبل فرنسا بسلاح ناري",
    "People executed by France by firing squad": "أشخاص أعدموا من قبل فرنسا رميا بالرصاص",
    "People executed by France by guillotine": "أشخاص أعدموا من قبل فرنسا بالمقصلة",
    "People executed by France by hanging": "أشخاص أعدموا من قبل فرنسا بالشنق",
    "People executed by France": "أشخاص أعدموا من قبل فرنسا",
    "People executed by Francoist Spain": "أشخاص أعدموا من قبل إسبانيا الفرانكوية",
    "People executed by Georgia (U.S. state)": "أشخاص أعدموا من قبل ولاية جورجيا",
    "People executed by Germany by burning": "أشخاص أعدموا من قبل ألمانيا بالحرق",
    "People executed by Germany by decapitation": "أشخاص أعدموا من قبل ألمانيا بقطع الرأس",
    "People executed by Germany by firearm": "أشخاص أعدموا من قبل ألمانيا بسلاح ناري",
    "People executed by Germany by firing squad": "أشخاص أعدموا من قبل ألمانيا رميا بالرصاص",
    "People executed by Germany by guillotine": "أشخاص أعدموا من قبل ألمانيا بالمقصلة",
    "People executed by Germany by hanging": "أشخاص أعدموا من قبل ألمانيا بالشنق",
    "People executed by Germany": "أشخاص أعدموا من قبل ألمانيا",
    "People executed by Ghana by firing squad": "أشخاص أعدموا من قبل غانا رميا بالرصاص",
    "People executed by Ghana": "أشخاص أعدموا من قبل غانا",
    "People executed by Greece by firing squad": "أشخاص أعدموا من قبل اليونان رميا بالرصاص",
    "People executed by Greece": "أشخاص أعدموا من قبل اليونان",
    "People executed by Grenada by firing squad": "أشخاص أعدموا من قبل غرينادا رميا بالرصاص",
    "People executed by Grenada": "أشخاص أعدموا من قبل غرينادا",
    "People executed by Guatemala by firearm": "أشخاص أعدموا من قبل غواتيمالا بسلاح ناري",
    "People executed by Guatemala by firing squad": "أشخاص أعدموا من قبل غواتيمالا رميا بالرصاص",
    "People executed by Guatemala": "أشخاص أعدموا من قبل غواتيمالا",
    "People executed by Guernsey": "أشخاص أعدموا من قبل غيرنزي",
    "People executed by Guinea by firearm": "أشخاص أعدموا من قبل غينيا بسلاح ناري",
    "People executed by Guinea by firing squad": "أشخاص أعدموا من قبل غينيا رميا بالرصاص",
    "People executed by Guinea by hanging": "أشخاص أعدموا من قبل غينيا بالشنق",
    "People executed by Guinea": "أشخاص أعدموا من قبل غينيا",
    "People executed by Haiti by firearm": "أشخاص أعدموا من قبل هايتي بسلاح ناري",
    "People executed by Haiti by firing squad": "أشخاص أعدموا من قبل هايتي رميا بالرصاص",
    "People executed by Haiti": "أشخاص أعدموا من قبل هايتي",
    "People executed by hanging by country": "أشخاص أعدموا حرقاً من قبل كانتري",
    "People executed by Hawaii by hanging": "أشخاص أعدموا من قبل هاواي بالشنق",
    "People executed by Hawaii": "أشخاص أعدموا من قبل هاواي",
    "People executed by Honduras by firing squad": "أشخاص أعدموا من قبل هندوراس رميا بالرصاص",
    "People executed by Honduras": "أشخاص أعدموا من قبل هندوراس",
    "People executed by Hong Kong": "أشخاص أعدموا من قبل هونغ كونغ",
    "People executed by Hungary by decapitation": "أشخاص أعدموا من قبل المجر بقطع الرأس",
    "People executed by Hungary by firing squad": "أشخاص أعدموا من قبل المجر رميا بالرصاص",
    "People executed by Hungary by hanging": "أشخاص أعدموا من قبل المجر بالشنق",
    "People executed by Hungary": "أشخاص أعدموا من قبل المجر",
    "People executed by Iceland by decapitation": "أشخاص أعدموا من قبل آيسلندا بقطع الرأس",
    "People executed by Iceland": "أشخاص أعدموا من قبل آيسلندا",
    "People executed by Idaho": "أشخاص أعدموا من قبل أيداهو",
    "People executed by Illinois by hanging": "أشخاص أعدموا من قبل إلينوي بالشنق",
    "People executed by Illinois": "أشخاص أعدموا من قبل إلينوي",
    "People executed by India by decapitation": "أشخاص أعدموا من قبل الهند بقطع الرأس",
    "People executed by India by firearm": "أشخاص أعدموا من قبل الهند بسلاح ناري",
    "People executed by India by hanging": "أشخاص أعدموا من قبل الهند بالشنق",
    "People executed by India": "أشخاص أعدموا من قبل الهند",
    "People executed by Indiana by hanging": "أشخاص أعدموا من قبل إنديانا بالشنق",
    "People executed by Indiana": "أشخاص أعدموا من قبل إنديانا",
    "People executed by Indonesia by firearm": "أشخاص أعدموا من قبل إندونيسيا بسلاح ناري",
    "People executed by Indonesia by firing squad": "أشخاص أعدموا من قبل إندونيسيا رميا بالرصاص",
    "People executed by Indonesia": "أشخاص أعدموا من قبل إندونيسيا",
    "People executed by international courts and tribunals": "أشخاص أعدموا من قبل محاكم وهيئات قضائية دولية",
    "People executed by Iowa by hanging": "أشخاص أعدموا من قبل آيوا بالشنق",
    "People executed by Iowa": "أشخاص أعدموا من قبل آيوا",
    "People executed by Iran by decapitation": "أشخاص أعدموا من قبل إيران بقطع الرأس",
    "People executed by Iran by firearm": "أشخاص أعدموا من قبل إيران بسلاح ناري",
    "People executed by Iran by firing squad": "أشخاص أعدموا من قبل إيران رميا بالرصاص",
    "People executed by Iran by hanging": "أشخاص أعدموا من قبل إيران بالشنق",
    "People executed by Iran": "أشخاص أعدموا من قبل إيران",
    "People executed by Iraq by firing squad": "أشخاص أعدموا من قبل العراق رميا بالرصاص",
    "People executed by Iraq by hanging": "أشخاص أعدموا من قبل العراق بالشنق",
    "People executed by Iraq": "أشخاص أعدموا من قبل العراق",
    "People executed by Ireland by burning": "أشخاص أعدموا من قبل أيرلندا بالحرق",
    "People executed by Ireland by firing squad": "أشخاص أعدموا من قبل أيرلندا رميا بالرصاص",
    "People executed by Ireland by hanging": "أشخاص أعدموا من قبل أيرلندا بالشنق",
    "People executed by Ireland": "أشخاص أعدموا من قبل أيرلندا",
    "People executed by Israel by firing squad": "أشخاص أعدموا من قبل إسرائيل رميا بالرصاص",
    "People executed by Israel by hanging": "أشخاص أعدموا من قبل إسرائيل بالشنق",
    "People executed by Israel": "أشخاص أعدموا من قبل إسرائيل",
    "People executed by Italy by firearm": "أشخاص أعدموا من قبل إيطاليا بسلاح ناري",
    "People executed by Italy by firing squad": "أشخاص أعدموا من قبل إيطاليا رميا بالرصاص",
    "People executed by Italy by hanging": "أشخاص أعدموا من قبل إيطاليا بالشنق",
    "People executed by Italy": "أشخاص أعدموا من قبل إيطاليا",
    "People executed by Jamaica by hanging": "أشخاص أعدموا من قبل جامايكا بالشنق",
    "People executed by Jamaica": "أشخاص أعدموا من قبل جامايكا",
    "People executed by Japan by burning": "أشخاص أعدموا من قبل اليابان بالحرق",
    "People executed by Japan by decapitation": "أشخاص أعدموا من قبل اليابان بقطع الرأس",
    "People executed by Japan by firearm": "أشخاص أعدموا من قبل اليابان بسلاح ناري",
    "People executed by Japan by firing squad": "أشخاص أعدموا من قبل اليابان رميا بالرصاص",
    "People executed by Japan by hanging": "أشخاص أعدموا من قبل اليابان بالشنق",
    "People executed by Japan": "أشخاص أعدموا من قبل اليابان",
    "People executed by Jersey by hanging": "أشخاص أعدموا من قبل جيرزي بالشنق",
    "People executed by Jersey": "أشخاص أعدموا من قبل جيرزي",
    "People executed by Jordan by hanging": "أشخاص أعدموا من قبل الأردن بالشنق",
    "People executed by Jordan": "أشخاص أعدموا من قبل الأردن",
    "People executed by Kansas by hanging": "أشخاص أعدموا من قبل كانساس بالشنق",
    "People executed by Kansas": "أشخاص أعدموا من قبل كانساس",
    "People executed by Kazakhstan by firearm": "أشخاص أعدموا من قبل كازاخستان بسلاح ناري",
    "People executed by Kazakhstan": "أشخاص أعدموا من قبل كازاخستان",
    "People executed by Kentucky by hanging": "أشخاص أعدموا من قبل كنتاكي بالشنق",
    "People executed by Kentucky": "أشخاص أعدموا من قبل كنتاكي",
    "People executed by Kenya by hanging": "أشخاص أعدموا من قبل كينيا بالشنق",
    "People executed by Kenya": "أشخاص أعدموا من قبل كينيا",
    "People executed by Kingdom of England by burning": "أشخاص أعدموا من قبل مملكة إنجلترا بالحرق",
    "People executed by Korea by decapitation": "أشخاص أعدموا من قبل كوريا بقطع الرأس",
    "People executed by Korea by firing squad": "أشخاص أعدموا من قبل كوريا رميا بالرصاص",
    "People executed by Korea by hanging": "أشخاص أعدموا من قبل كوريا بالشنق",
    "People executed by Korea": "أشخاص أعدموا من قبل كوريا",
    "People executed by Laos by decapitation": "أشخاص أعدموا من قبل لاوس بقطع الرأس",
    "People executed by Laos": "أشخاص أعدموا من قبل لاوس",
    "People executed by Later Tang": "أشخاص أعدموا من قبل سلالة تانغ المتأخرة الحاكمة",
    "People executed by Lebanon by firing squad": "أشخاص أعدموا من قبل لبنان رميا بالرصاص",
    "People executed by Lebanon": "أشخاص أعدموا من قبل لبنان",
    "People executed by Liberia by firing squad": "أشخاص أعدموا من قبل ليبيريا رميا بالرصاص",
    "People executed by Liberia by hanging": "أشخاص أعدموا من قبل ليبيريا بالشنق",
    "People executed by Liberia": "أشخاص أعدموا من قبل ليبيريا",
    "People executed by Libya by hanging": "أشخاص أعدموا من قبل ليبيا بالشنق",
    "People executed by Libya": "أشخاص أعدموا من قبل ليبيا",
    "People executed by Liechtenstein by decapitation": "أشخاص أعدموا من قبل ليختنشتاين بقطع الرأس",
    "People executed by Liechtenstein": "أشخاص أعدموا من قبل ليختنشتاين",
    "People executed by Lithuania by firearm": "أشخاص أعدموا من قبل ليتوانيا بسلاح ناري",
    "People executed by Lithuania by firing squad": "أشخاص أعدموا من قبل ليتوانيا رميا بالرصاص",
    "People executed by Lithuania": "أشخاص أعدموا من قبل ليتوانيا",
    "People executed by Louisiana": "أشخاص أعدموا من قبل لويزيانا",
    "People executed by Luxembourg by firing squad": "أشخاص أعدموا من قبل لوكسمبورغ رميا بالرصاص",
    "People executed by Luxembourg": "أشخاص أعدموا من قبل لوكسمبورغ",
    "People executed by Maine by hanging": "أشخاص أعدموا من قبل مين بالشنق",
    "People executed by Maine": "أشخاص أعدموا من قبل مين",
    "People executed by Malawi by hanging": "أشخاص أعدموا من قبل ملاوي بالشنق",
    "People executed by Malawi": "أشخاص أعدموا من قبل ملاوي",
    "People executed by Malaysia by hanging": "أشخاص أعدموا من قبل ماليزيا بالشنق",
    "People executed by Malaysia": "أشخاص أعدموا من قبل ماليزيا",
    "People executed by Malta by hanging": "أشخاص أعدموا من قبل مالطا بالشنق",
    "People executed by Malta": "أشخاص أعدموا من قبل مالطا",
    "People executed by Mandatory Palestine by hanging": "أشخاص أعدموا من قبل الانتداب البريطاني على فلسطين بالشنق",
    "People executed by Mandatory Palestine": "أشخاص أعدموا من قبل الانتداب البريطاني على فلسطين",
    "People executed by Maryland by hanging": "أشخاص أعدموا من قبل ماريلند بالشنق",
    "People executed by Maryland": "أشخاص أعدموا من قبل ماريلند",
    "People executed by Massachusetts by firing squad": "أشخاص أعدموا من قبل ماساتشوستس رميا بالرصاص",
    "People executed by Massachusetts by hanging": "أشخاص أعدموا من قبل ماساتشوستس بالشنق",
    "People executed by Massachusetts": "أشخاص أعدموا من قبل ماساتشوستس",
    "People executed by Mauritius by decapitation": "أشخاص أعدموا من قبل موريشيوس بقطع الرأس",
    "People executed by Mauritius by hanging": "أشخاص أعدموا من قبل موريشيوس بالشنق",
    "People executed by Mauritius": "أشخاص أعدموا من قبل موريشيوس",
    "People executed by Mexico by firearm": "أشخاص أعدموا من قبل المكسيك بسلاح ناري",
    "People executed by Mexico by firing squad": "أشخاص أعدموا من قبل المكسيك رميا بالرصاص",
    "People executed by Mexico by hanging": "أشخاص أعدموا من قبل المكسيك بالشنق",
    "People executed by Mexico": "أشخاص أعدموا من قبل المكسيك",
    "People executed by Minnesota by hanging": "أشخاص أعدموا من قبل منيسوتا بالشنق",
    "People executed by Minnesota": "أشخاص أعدموا من قبل منيسوتا",
    "People executed by Mississippi by hanging": "أشخاص أعدموا من قبل مسيسيبي بالشنق",
    "People executed by Mississippi": "أشخاص أعدموا من قبل مسيسيبي",
    "People executed by Missouri by hanging": "أشخاص أعدموا من قبل ميزوري بالشنق",
    "People executed by Missouri": "أشخاص أعدموا من قبل ميزوري",
    "People executed by Mongolia by decapitation": "أشخاص أعدموا من قبل منغوليا بقطع الرأس",
    "People executed by Mongolia by firearm": "أشخاص أعدموا من قبل منغوليا بسلاح ناري",
    "People executed by Mongolia": "أشخاص أعدموا من قبل منغوليا",
    "People executed by Montana by hanging": "أشخاص أعدموا من قبل مونتانا بالشنق",
    "People executed by Montana": "أشخاص أعدموا من قبل مونتانا",
    "People executed by Montenegro by decapitation": "أشخاص أعدموا من قبل الجبل الأسود بقطع الرأس",
    "People executed by Montenegro": "أشخاص أعدموا من قبل الجبل الأسود",
    "People executed by Morocco by decapitation": "أشخاص أعدموا من قبل المغرب بقطع الرأس",
    "People executed by Morocco by firing squad": "أشخاص أعدموا من قبل المغرب رميا بالرصاص",
    "People executed by Morocco": "أشخاص أعدموا من قبل المغرب",
    "People executed by Mozambique": "أشخاص أعدموا من قبل موزمبيق",
    "People executed by Myanmar by hanging": "أشخاص أعدموا من قبل ميانمار بالشنق",
    "People executed by Myanmar": "أشخاص أعدموا من قبل ميانمار",
    "People executed by Nazi Germany by firearm": "أشخاص أعدموا من قبل ألمانيا النازية بسلاح ناري",
    "People executed by Nazi Germany by firing squad": "أشخاص أعدموا من قبل ألمانيا النازية رميا بالرصاص",
    "People executed by Nazi Germany by guillotine": "أشخاص أعدموا من قبل ألمانيا النازية بالمقصلة",
    "People executed by Nazi Germany by hanging": "أشخاص أعدموا من قبل ألمانيا النازية بالشنق",
    "People executed by Nazi Germany by nationality": "أشخاص أعدموا من قبل ألمانيا النازية حسب الجنسية",
    "People executed by Nazi Germany": "أشخاص أعدموا من قبل ألمانيا النازية",
    "People executed by Nebraska by hanging": "أشخاص أعدموا من قبل نبراسكا بالشنق",
    "People executed by Nebraska": "أشخاص أعدموا من قبل نبراسكا",
    "People executed by Nepal by decapitation": "أشخاص أعدموا من قبل نيبال بقطع الرأس",
    "People executed by Nepal by firearm": "أشخاص أعدموا من قبل نيبال بسلاح ناري",
    "People executed by Nepal by hanging": "أشخاص أعدموا من قبل نيبال بالشنق",
    "People executed by Nepal": "أشخاص أعدموا من قبل نيبال",
    "People executed by Nevada by firing squad": "أشخاص أعدموا من قبل نيفادا رميا بالرصاص",
    "People executed by Nevada by hanging": "أشخاص أعدموا من قبل نيفادا بالشنق",
    "People executed by Nevada": "أشخاص أعدموا من قبل نيفادا",
    "People executed by New Hampshire by hanging": "أشخاص أعدموا من قبل نيوهامشير بالشنق",
    "People executed by New Hampshire": "أشخاص أعدموا من قبل نيوهامشير",
    "People executed by New Jersey by hanging": "أشخاص أعدموا من قبل نيوجيرسي بالشنق",
    "People executed by New Jersey": "أشخاص أعدموا من قبل نيوجيرسي",
    "People executed by New Mexico by hanging": "أشخاص أعدموا من قبل نيومكسيكو بالشنق",
    "People executed by New Mexico": "أشخاص أعدموا من قبل نيومكسيكو",
    "People executed by New South Wales": "أشخاص أعدموا من قبل نيوساوث ويلز",
    "People executed by New Spain": "أشخاص أعدموا من قبل إسبانيا الجديدة",
    "People executed by New York (state) by hanging": "أشخاص أعدموا من قبل ولاية نيويورك بالشنق",
    "People executed by New York (state)": "أشخاص أعدموا من قبل ولاية نيويورك",
    "People executed by New Zealand by hanging": "أشخاص أعدموا من قبل نيوزيلندا بالشنق",
    "People executed by New Zealand": "أشخاص أعدموا من قبل نيوزيلندا",
    "People executed by Newfoundland": "أشخاص أعدموا من قبل نيوفاوندلاند",
    "People executed by Nigeria by firing squad": "أشخاص أعدموا من قبل نيجيريا رميا بالرصاص",
    "People executed by Nigeria by hanging": "أشخاص أعدموا من قبل نيجيريا بالشنق",
    "People executed by Nigeria": "أشخاص أعدموا من قبل نيجيريا",
    "People executed by Norfolk Island": "أشخاص أعدموا من قبل جزيرة نورفولك",
    "People executed by North Carolina by hanging": "أشخاص أعدموا من قبل كارولاينا الشمالية بالشنق",
    "People executed by North Carolina": "أشخاص أعدموا من قبل كارولاينا الشمالية",
    "People executed by North Dakota by hanging": "أشخاص أعدموا من قبل داكوتا الشمالية بالشنق",
    "People executed by North Dakota": "أشخاص أعدموا من قبل داكوتا الشمالية",
    "People executed by North Korea by firing squad": "أشخاص أعدموا من قبل كوريا الشمالية رميا بالرصاص",
    "People executed by North Korea": "أشخاص أعدموا من قبل كوريا الشمالية",
    "People executed by Northern Ireland by hanging": "أشخاص أعدموا من قبل أيرلندا الشمالية بالشنق",
    "People executed by Northern Ireland": "أشخاص أعدموا من قبل أيرلندا الشمالية",
    "People executed by Norway by burning": "أشخاص أعدموا من قبل النرويج بالحرق",
    "People executed by Norway by decapitation": "أشخاص أعدموا من قبل النرويج بقطع الرأس",
    "People executed by Norway by firearm": "أشخاص أعدموا من قبل النرويج بسلاح ناري",
    "People executed by Norway by firing squad": "أشخاص أعدموا من قبل النرويج رميا بالرصاص",
    "People executed by Norway by hanging": "أشخاص أعدموا من قبل النرويج بالشنق",
    "People executed by Norway": "أشخاص أعدموا من قبل النرويج",
    "People executed by Nova Scotia": "أشخاص أعدموا من قبل نوفا سكوشا",
    "People executed by Ohio by hanging": "أشخاص أعدموا من قبل أوهايو بالشنق",
    "People executed by Ohio": "أشخاص أعدموا من قبل أوهايو",
    "People executed by Oklahoma": "أشخاص أعدموا من قبل أوكلاهوما",
    "People executed by Oregon by hanging": "أشخاص أعدموا من قبل أوريغن بالشنق",
    "People executed by Oregon": "أشخاص أعدموا من قبل أوريغن",
    "People executed by Pakistan by firearm": "أشخاص أعدموا من قبل باكستان بسلاح ناري",
    "People executed by Pakistan by hanging": "أشخاص أعدموا من قبل باكستان بالشنق",
    "People executed by Pakistan": "أشخاص أعدموا من قبل باكستان",
    "People executed by Panama by firearm": "أشخاص أعدموا من قبل بنما بسلاح ناري",
    "People executed by Panama": "أشخاص أعدموا من قبل بنما",
    "People executed by Papua New Guinea by hanging": "أشخاص أعدموا من قبل بابوا غينيا الجديدة بالشنق",
    "People executed by Papua New Guinea": "أشخاص أعدموا من قبل بابوا غينيا الجديدة",
    "People executed by Pennsylvania by hanging": "أشخاص أعدموا من قبل بنسلفانيا بالشنق",
    "People executed by Pennsylvania": "أشخاص أعدموا من قبل بنسلفانيا",
    "People executed by Peru by firearm": "أشخاص أعدموا من قبل بيرو بسلاح ناري",
    "People executed by Peru": "أشخاص أعدموا من قبل بيرو",
    "People executed by Poland by burning": "أشخاص أعدموا من قبل بولندا بالحرق",
    "People executed by Poland by decapitation": "أشخاص أعدموا من قبل بولندا بقطع الرأس",
    "People executed by Poland by firearm": "أشخاص أعدموا من قبل بولندا بسلاح ناري",
    "People executed by Poland by firing squad": "أشخاص أعدموا من قبل بولندا رميا بالرصاص",
    "People executed by Poland by hanging": "أشخاص أعدموا من قبل بولندا بالشنق",
    "People executed by Poland": "أشخاص أعدموا من قبل بولندا",
    "People executed by Portugal by burning": "أشخاص أعدموا من قبل البرتغال بالحرق",
    "People executed by Portugal by decapitation": "أشخاص أعدموا من قبل البرتغال بقطع الرأس",
    "People executed by Portugal by firing squad": "أشخاص أعدموا من قبل البرتغال رميا بالرصاص",
    "People executed by Portugal by hanging": "أشخاص أعدموا من قبل البرتغال بالشنق",
    "People executed by Portugal": "أشخاص أعدموا من قبل البرتغال",
    "People executed by Prussia": "أشخاص أعدموا من قبل بروسيا",
    "People executed by Queensland": "أشخاص أعدموا من قبل كوينزلاند",
    "People executed by Rhode Island by hanging": "أشخاص أعدموا من قبل رود آيلاند بالشنق",
    "People executed by Rhode Island": "أشخاص أعدموا من قبل رود آيلاند",
    "People executed by Romania by firearm": "أشخاص أعدموا من قبل رومانيا بسلاح ناري",
    "People executed by Romania by firing squad": "أشخاص أعدموا من قبل رومانيا رميا بالرصاص",
    "People executed by Romania": "أشخاص أعدموا من قبل رومانيا",
    "People executed by Russia by burning": "أشخاص أعدموا من قبل روسيا بالحرق",
    "People executed by Russia by decapitation": "أشخاص أعدموا من قبل روسيا بقطع الرأس",
    "People executed by Russia by firearm": "أشخاص أعدموا من قبل روسيا بسلاح ناري",
    "People executed by Russia by firing squad": "أشخاص أعدموا من قبل روسيا رميا بالرصاص",
    "People executed by Russia by hanging": "أشخاص أعدموا من قبل روسيا بالشنق",
    "People executed by Russia": "أشخاص أعدموا من قبل روسيا",
    "People executed by Rwanda by firing squad": "أشخاص أعدموا من قبل رواندا رميا بالرصاص",
    "People executed by Rwanda": "أشخاص أعدموا من قبل رواندا",
    "People executed by Safavid Iran": "أشخاص أعدموا من قبل إيران الصفوية",
    "People executed by Saint Kitts and Nevis by hanging": "أشخاص أعدموا من قبل سانت كيتس ونيفيس بالشنق",
    "People executed by Saint Kitts and Nevis": "أشخاص أعدموا من قبل سانت كيتس ونيفيس",
    "People executed by Saint Lucia by hanging": "أشخاص أعدموا من قبل سانت لوسيا بالشنق",
    "People executed by Saint Lucia": "أشخاص أعدموا من قبل سانت لوسيا",
    "People executed by Saint Vincent and the Grenadines by hanging": "أشخاص أعدموا من قبل سانت فنسنت وجزر غرينادين بالشنق",
    "People executed by Saint Vincent and the Grenadines": "أشخاص أعدموا من قبل سانت فنسنت وجزر غرينادين",
    "People executed by Saudi Arabia by decapitation": "أشخاص أعدموا من قبل السعودية بقطع الرأس",
    "People executed by Saudi Arabia by firearm": "أشخاص أعدموا من قبل السعودية بسلاح ناري",
    "People executed by Saudi Arabia": "أشخاص أعدموا من قبل السعودية",
    "People executed by Saxony": "أشخاص أعدموا من قبل ساكسونيا",
    "People executed by Scotland by burning": "أشخاص أعدموا من قبل إسكتلندا بالحرق",
    "People executed by Scotland by decapitation": "أشخاص أعدموا من قبل إسكتلندا بقطع الرأس",
    "People executed by Scotland by hanging": "أشخاص أعدموا من قبل إسكتلندا بالشنق",
    "People executed by Scotland": "أشخاص أعدموا من قبل إسكتلندا",
    "People executed by Senegal by firing squad": "أشخاص أعدموا من قبل السنغال رميا بالرصاص",
    "People executed by Senegal": "أشخاص أعدموا من قبل السنغال",
    "People executed by Serbia by firing squad": "أشخاص أعدموا من قبل صربيا رميا بالرصاص",
    "People executed by Serbia": "أشخاص أعدموا من قبل صربيا",
    "People executed by Shu Han": "أشخاص أعدموا من قبل مملكة شو",
    "People executed by Sierra Leone by hanging": "أشخاص أعدموا من قبل سيراليون بالشنق",
    "People executed by Sierra Leone": "أشخاص أعدموا من قبل سيراليون",
    "People executed by Singapore by hanging": "أشخاص أعدموا من قبل سنغافورة بالشنق",
    "People executed by Somalia by firing squad": "أشخاص أعدموا من قبل الصومال رميا بالرصاص",
    "People executed by Somalia": "أشخاص أعدموا من قبل الصومال",
    "People executed by South Africa by firing squad": "أشخاص أعدموا من قبل جنوب إفريقيا رميا بالرصاص",
    "People executed by South Africa by hanging": "أشخاص أعدموا من قبل جنوب إفريقيا بالشنق",
    "People executed by South Africa": "أشخاص أعدموا من قبل جنوب إفريقيا",
    "People executed by South Australia": "أشخاص أعدموا من قبل جنوب أستراليا",
    "People executed by South Carolina by hanging": "أشخاص أعدموا من قبل كارولاينا الجنوبية بالشنق",
    "People executed by South Carolina": "أشخاص أعدموا من قبل كارولاينا الجنوبية",
    "People executed by South Dakota": "أشخاص أعدموا من قبل داكوتا الجنوبية",
    "People executed by South Korea by firing squad": "أشخاص أعدموا من قبل كوريا الجنوبية رميا بالرصاص",
    "People executed by South Korea by hanging": "أشخاص أعدموا من قبل كوريا الجنوبية بالشنق",
    "People executed by South Korea": "أشخاص أعدموا من قبل كوريا الجنوبية",
    "People executed by South Vietnam by firearm": "أشخاص أعدموا من قبل فيتنام الجنوبية بسلاح ناري",
    "People executed by South Vietnam by firing squad": "أشخاص أعدموا من قبل فيتنام الجنوبية رميا بالرصاص",
    "People executed by South Vietnam by guillotine": "أشخاص أعدموا من قبل فيتنام الجنوبية بالمقصلة",
    "People executed by South Vietnam": "أشخاص أعدموا من قبل فيتنام الجنوبية",
    "People executed by Spain by burning": "أشخاص أعدموا من قبل إسبانيا بالحرق",
    "People executed by Spain by decapitation": "أشخاص أعدموا من قبل إسبانيا بقطع الرأس",
    "People executed by Spain by firearm": "أشخاص أعدموا من قبل إسبانيا بسلاح ناري",
    "People executed by Spain by firing squad": "أشخاص أعدموا من قبل إسبانيا رميا بالرصاص",
    "People executed by Spain by hanging": "أشخاص أعدموا من قبل إسبانيا بالشنق",
    "People executed by Spain": "أشخاص أعدموا من قبل إسبانيا",
    "People executed by Sri Lanka by decapitation": "أشخاص أعدموا من قبل سريلانكا بقطع الرأس",
    "People executed by Sri Lanka by firing squad": "أشخاص أعدموا من قبل سريلانكا رميا بالرصاص",
    "People executed by Sri Lanka by hanging": "أشخاص أعدموا من قبل سريلانكا بالشنق",
    "People executed by Sri Lanka": "أشخاص أعدموا من قبل سريلانكا",
    "People executed by Sudan by firing squad": "أشخاص أعدموا من قبل السودان رميا بالرصاص",
    "People executed by Sudan by hanging": "أشخاص أعدموا من قبل السودان بالشنق",
    "People executed by Sudan": "أشخاص أعدموا من قبل السودان",
    "People executed by Suriname by firing squad": "أشخاص أعدموا من قبل سورينام رميا بالرصاص",
    "People executed by Suriname": "أشخاص أعدموا من قبل سورينام",
    "People executed by Sweden by burning": "أشخاص أعدموا من قبل السويد بالحرق",
    "People executed by Sweden by decapitation": "أشخاص أعدموا من قبل السويد بقطع الرأس",
    "People executed by Sweden by hanging": "أشخاص أعدموا من قبل السويد بالشنق",
    "People executed by Sweden": "أشخاص أعدموا من قبل السويد",
    "People executed by Switzerland by burning": "أشخاص أعدموا من قبل سويسرا بالحرق",
    "People executed by Switzerland by decapitation": "أشخاص أعدموا من قبل سويسرا بقطع الرأس",
    "People executed by Switzerland by firing squad": "أشخاص أعدموا من قبل سويسرا رميا بالرصاص",
    "People executed by Switzerland by guillotine": "أشخاص أعدموا من قبل سويسرا بالمقصلة",
    "People executed by Switzerland": "أشخاص أعدموا من قبل سويسرا",
    "People executed by Syria by firing squad": "أشخاص أعدموا من قبل سوريا رميا بالرصاص",
    "People executed by Syria by hanging": "أشخاص أعدموا من قبل سوريا بالشنق",
    "People executed by Syria": "أشخاص أعدموا من قبل سوريا",
    "People executed by Taiwan by firearm": "أشخاص أعدموا من قبل تايوان بسلاح ناري",
    "People executed by Taiwan": "أشخاص أعدموا من قبل تايوان",
    "People executed by Tasmania": "أشخاص أعدموا من قبل تسمانيا",
    "People executed by Tennessee by hanging": "أشخاص أعدموا من قبل تينيسي بالشنق",
    "People executed by Tennessee": "أشخاص أعدموا من قبل تينيسي",
    "People executed by Texas by hanging": "أشخاص أعدموا من قبل تكساس بالشنق",
    "People executed by Texas": "أشخاص أعدموا من قبل تكساس",
    "People executed by Thailand by decapitation": "أشخاص أعدموا من قبل تايلاند بقطع الرأس",
    "People executed by Thailand by firearm": "أشخاص أعدموا من قبل تايلاند بسلاح ناري",
    "People executed by Thailand": "أشخاص أعدموا من قبل تايلاند",
    "People executed by the Abbasid Caliphate": "أشخاص أعدموا من قبل الدولة العباسية",
    "People executed by the Achaemenid Empire": "أشخاص أعدموا من قبل أخمينيون",
    "People executed by the Austrian Empire": "أشخاص أعدموا من قبل الإمبراطورية النمساوية",
    "People executed by the Bahamas by hanging": "أشخاص أعدموا من قبل باهاماس بالشنق",
    "People executed by the Bahamas": "أشخاص أعدموا من قبل باهاماس",
    "People executed by the British military by decapitation": "أشخاص أعدموا من قبل الجيش البريطاني بقطع الرأس",
    "People executed by the British military by firearm": "أشخاص أعدموا من قبل الجيش البريطاني بسلاح ناري",
    "People executed by the British military by firing squad": "أشخاص أعدموا من قبل الجيش البريطاني رميا بالرصاص",
    "People executed by the British military by hanging": "أشخاص أعدموا من قبل الجيش البريطاني بالشنق",
    "People executed by the Buyid dynasty": "أشخاص أعدموا من قبل بويهيون",
    "People executed by the Byzantine Empire": "أشخاص أعدموا من قبل الإمبراطورية البيزنطية",
    "People executed by the Central African Republic by firing squad": "أشخاص أعدموا من قبل جمهورية إفريقيا الوسطى رميا بالرصاص",
    "People executed by the Central African Republic": "أشخاص أعدموا من قبل جمهورية إفريقيا الوسطى",
    "People executed by the Colony of Virginia": "أشخاص أعدموا من قبل مستعمرة فرجينيا",
    "People executed by the Confederate States of America by hanging": "أشخاص أعدموا من قبل الولايات الكونفدرالية الأمريكية بالشنق",
    "People executed by the Confederate States of America": "أشخاص أعدموا من قبل الولايات الكونفدرالية الأمريكية",
    "People executed by the Congo Free State": "أشخاص أعدموا من قبل دولة الكونغو الحرة",
    "People executed by the Czechoslovak Socialist Republic by hanging": "أشخاص أعدموا من قبل جمهورية تشيكوسلوفاكيا الاشتراكية بالشنق",
    "People executed by the Czechoslovak Socialist Republic": "أشخاص أعدموا من قبل جمهورية تشيكوسلوفاكيا الاشتراكية",
    "People executed by the Democratic Republic of the Congo by hanging": "أشخاص أعدموا من قبل جمهورية الكونغو الديمقراطية بالشنق",
    "People executed by the Democratic Republic of the Congo": "أشخاص أعدموا من قبل جمهورية الكونغو الديمقراطية",
    "People executed by the Dominican Republic": "أشخاص أعدموا من قبل جمهورية الدومينيكان",
    "People executed by the Duchy of Milan": "أشخاص أعدموا من قبل دوقية ميلانو",
    "People executed by the Duchy of Modena and Reggio": "أشخاص أعدموا من قبل دوقية مودينا وريدجو",
    "People executed by the Dutch Republic": "أشخاص أعدموا من قبل جمهورية هولندا",
    "People executed by the Electorate of Cologne": "أشخاص أعدموا من قبل انتخابية كولونيا",
    "People executed by the Fatimid Caliphate": "أشخاص أعدموا من قبل الدولة الفاطمية",
    "People executed by the First French Empire by guillotine": "أشخاص أعدموا من قبل الإمبراطورية الفرنسية الأولى بالمقصلة",
    "People executed by the First French Empire": "أشخاص أعدموا من قبل الإمبراطورية الفرنسية الأولى",
    "People executed by the French Fifth Republic by guillotine": "أشخاص أعدموا من قبل الجمهورية الفرنسية الخامسة بالمقصلة",
    "People executed by the French Fifth Republic": "أشخاص أعدموا من قبل الجمهورية الفرنسية الخامسة",
    "People executed by the French Fourth Republic by guillotine": "أشخاص أعدموا من قبل الجمهورية الفرنسية الرابعة بالمقصلة",
    "People executed by the French Fourth Republic": "أشخاص أعدموا من قبل الجمهورية الفرنسية الرابعة",
    "People executed by the French military by firearm": "أشخاص أعدموا من قبل الجيش الفرنسي بسلاح ناري",
    "People executed by the French military by firing squad": "أشخاص أعدموا من قبل الجيش الفرنسي رميا بالرصاص",
    "People executed by the French military by guillotine": "أشخاص أعدموا من قبل الجيش الفرنسي بالمقصلة",
    "People executed by the French military by hanging": "أشخاص أعدموا من قبل الجيش الفرنسي بالشنق",
    "People executed by the French Third Republic by firing squad": "أشخاص أعدموا من قبل الجمهورية الفرنسية الثالثة رميا بالرصاص",
    "People executed by the French Third Republic by guillotine": "أشخاص أعدموا من قبل الجمهورية الفرنسية الثالثة بالمقصلة",
    "People executed by the French Third Republic": "أشخاص أعدموا من قبل الجمهورية الفرنسية الثالثة",
    "People executed by the Gambia": "أشخاص أعدموا من قبل غامبيا",
    "People executed by the German Empire": "أشخاص أعدموا من قبل الإمبراطورية الألمانية",
    "People executed by the Ghaznavid Empire": "أشخاص أعدموا من قبل الدولة الغزنوية",
    "People executed by the Golden Horde": "أشخاص أعدموا من قبل القبيلة الذهبية",
    "People executed by the Grand Duchy of Finland": "أشخاص أعدموا من قبل دوقية فنلندا الكبرى",
    "People executed by the Han dynasty by decapitation": "أشخاص أعدموا من قبل مملكة هان بقطع الرأس",
    "People executed by the Han dynasty": "أشخاص أعدموا من قبل مملكة هان",
    "People executed by the Holy Roman Empire by hanging": "أشخاص أعدموا من قبل الإمبراطورية الرومانية المقدسة بالشنق",
    "People executed by the Holy Roman Empire": "أشخاص أعدموا من قبل الإمبراطورية الرومانية المقدسة",
    "People executed by the House of Lancaster": "أشخاص أعدموا من قبل الهاوس في لانكستر",
    "People executed by the House of York": "أشخاص أعدموا من قبل الهاوس في يورك",
    "People executed by the Independent State of Croatia": "أشخاص أعدموا من قبل دولة كرواتيا المستقلة",
    "People executed by the International Military Tribunal in Nuremberg": "أشخاص أعدموا من قبل المحكمة العسكرية الدولية في نورنبيرغ",
    "People executed by the Irish Free State": "أشخاص أعدموا من قبل الدولة الأيرلندية الحرة",
    "People executed by the Isle of Man": "أشخاص أعدموا من قبل جزيرة مان",
    "People executed by the Italian Social Republic": "أشخاص أعدموا من قبل الجمهورية الإيطالية الاشتراكية",
    "People executed by the Jin dynasty (1115–1234)": "أشخاص أعدموا من قبل أسرة جين (1115–1234)",
    "People executed by the Jin dynasty (266–420) by decapitation": "أشخاص أعدموا من قبل أسرة جين (266–420) بقطع الرأس",
    "People executed by the Jin dynasty (266–420)": "أشخاص أعدموا من قبل أسرة جين (266–420)",
    "People executed by the July Monarchy": "أشخاص أعدموا من قبل ملكية يوليو",
    "People executed by the Kalmar Union": "أشخاص أعدموا من قبل اتحاد كالمار",
    "People executed by the Kingdom of England by burning": "أشخاص أعدموا من قبل مملكة إنجلترا بالحرق",
    "People executed by the Kingdom of England by decapitation": "أشخاص أعدموا من قبل مملكة إنجلترا بقطع الرأس",
    "People executed by the Kingdom of England by firearm": "أشخاص أعدموا من قبل مملكة إنجلترا بسلاح ناري",
    "People executed by the Kingdom of England by hanging": "أشخاص أعدموا من قبل مملكة إنجلترا بالشنق",
    "People executed by the Kingdom of England": "أشخاص أعدموا من قبل مملكة إنجلترا",
    "People executed by the Kingdom of Great Britain": "أشخاص أعدموا من قبل مملكة بريطانيا العظمى",
    "People executed by the Kingdom of Ireland by hanging": "أشخاص أعدموا من قبل مملكة أيرلندا بالشنق",
    "People executed by the Kingdom of Ireland": "أشخاص أعدموا من قبل مملكة أيرلندا",
    "People executed by the Kingdom of Kongo": "أشخاص أعدموا من قبل مملكة الكونغو",
    "People executed by the Kingdom of Naples": "أشخاص أعدموا من قبل مملكة نابولي",
    "People executed by the Kingdom of Romania": "أشخاص أعدموا من قبل مملكة رومانيا",
    "People executed by the Kingdom of Scotland by burning": "أشخاص أعدموا من قبل مملكة إسكتلندا بالحرق",
    "People executed by the Kingdom of Scotland by decapitation": "أشخاص أعدموا من قبل مملكة إسكتلندا بقطع الرأس",
    "People executed by the Kingdom of Scotland by hanging": "أشخاص أعدموا من قبل مملكة إسكتلندا بالشنق",
    "People executed by the Kingdom of Scotland": "أشخاص أعدموا من قبل مملكة إسكتلندا",
    "People executed by the Kingdom of Sicily": "أشخاص أعدموا من قبل مملكة صقلية",
    "People executed by the Liao dynasty by decapitation": "أشخاص أعدموا من قبل مملكة لياو بقطع الرأس",
    "People executed by the Liao dynasty": "أشخاص أعدموا من قبل مملكة لياو",
    "People executed by the Ming dynasty by decapitation": "أشخاص أعدموا من قبل سلالة مينغ الحاكمة بقطع الرأس",
    "People executed by the Ming dynasty": "أشخاص أعدموا من قبل سلالة مينغ الحاكمة",
    "People executed by the Mongol Empire": "أشخاص أعدموا من قبل إمبراطورية المغول",
    "People executed by the Mughal Empire": "أشخاص أعدموا من قبل سلطنة مغول الهند",
    "People executed by the Neo-Assyrian Empire": "أشخاص أعدموا من قبل إمبراطورية آشورية حديثة",
    "People executed by the Netherlands by burning": "أشخاص أعدموا من قبل هولندا بالحرق",
    "People executed by the Netherlands by decapitation": "أشخاص أعدموا من قبل هولندا بقطع الرأس",
    "People executed by the Netherlands by firearm": "أشخاص أعدموا من قبل هولندا بسلاح ناري",
    "People executed by the Netherlands by firing squad": "أشخاص أعدموا من قبل هولندا رميا بالرصاص",
    "People executed by the Netherlands by hanging": "أشخاص أعدموا من قبل هولندا بالشنق",
    "People executed by the Netherlands": "أشخاص أعدموا من قبل هولندا",
    "People executed by the Ottoman Empire by decapitation": "أشخاص أعدموا من قبل الدولة العثمانية بقطع الرأس",
    "People executed by the Ottoman Empire by firing squad": "أشخاص أعدموا من قبل الدولة العثمانية رميا بالرصاص",
    "People executed by the Ottoman Empire by hanging": "أشخاص أعدموا من قبل الدولة العثمانية بالشنق",
    "People executed by the Ottoman Empire": "أشخاص أعدموا من قبل الدولة العثمانية",
    "People executed by the Papal States by burning": "أشخاص أعدموا من قبل الدولة البابوية بالحرق",
    "People executed by the Papal States by decapitation": "أشخاص أعدموا من قبل الدولة البابوية بقطع الرأس",
    "People executed by the Papal States by hanging": "أشخاص أعدموا من قبل الدولة البابوية بالشنق",
    "People executed by the Papal States": "أشخاص أعدموا من قبل الدولة البابوية",
    "People executed by the Philippines by firing squad": "أشخاص أعدموا من قبل الفلبين رميا بالرصاص",
    "People executed by the Philippines by hanging": "أشخاص أعدموا من قبل الفلبين بالشنق",
    "People executed by the Philippines": "أشخاص أعدموا من قبل الفلبين",
    "People executed by the Polish–Lithuanian Commonwealth": "أشخاص أعدموا من قبل الكومنولث البولندي الليتواني",
    "People executed by the Qin dynasty": "أشخاص أعدموا من قبل سلالة تشين الحاكمة",
    "People executed by the Qing dynasty by decapitation": "أشخاص أعدموا من قبل مملكة تشينغ بقطع الرأس",
    "People executed by the Qing dynasty by firearm": "أشخاص أعدموا من قبل مملكة تشينغ بسلاح ناري",
    "People executed by the Qing dynasty": "أشخاص أعدموا من قبل مملكة تشينغ",
    "People executed by the Rashidun Caliphate": "أشخاص أعدموا من قبل الخلافة الراشدة",
    "People executed by the Republic of China": "أشخاص أعدموا من قبل جمهورية الصين",
    "People executed by the Republic of Genoa": "أشخاص أعدموا من قبل جمهورية جنوة",
    "People executed by the Republic of Ireland": "أشخاص أعدموا من قبل جمهورية أيرلندا",
    "People executed by the Republic of the Congo": "أشخاص أعدموا من قبل جمهورية الكونغو",
    "People executed by the Republic of Venice": "أشخاص أعدموا من قبل جمهورية البندقية",
    "People executed by the Roman Empire": "أشخاص أعدموا من قبل الإمبراطورية الرومانية",
    "People executed by the Roman Kingdom": "أشخاص أعدموا من قبل المملكة الرومانية",
    "People executed by the Roman Republic": "أشخاص أعدموا من قبل الجمهورية الرومانية",
    "People executed by the Russian Empire by decapitation": "أشخاص أعدموا من قبل الإمبراطورية الروسية بقطع الرأس",
    "People executed by the Russian Empire by firing squad": "أشخاص أعدموا من قبل الإمبراطورية الروسية رميا بالرصاص",
    "People executed by the Russian Empire by hanging": "أشخاص أعدموا من قبل الإمبراطورية الروسية بالشنق",
    "People executed by the Russian Empire": "أشخاص أعدموا من قبل الإمبراطورية الروسية",
    "People executed by the Sasanian Empire": "أشخاص أعدموا من قبل الإمبراطورية الساسانية",
    "People executed by the Second French Empire by guillotine": "أشخاص أعدموا من قبل الإمبراطورية الفرنسية الثانية بالمقصلة",
    "People executed by the Second French Empire": "أشخاص أعدموا من قبل الإمبراطورية الفرنسية الثانية",
    "People executed by the Second Polish Republic": "أشخاص أعدموا من قبل الجمهورية البولندية الثانية",
    "People executed by the Socialist Republic of Romania": "أشخاص أعدموا من قبل جمهورية رومانيا الاشتراكية",
    "People executed by the Solomon Islands by hanging": "أشخاص أعدموا من قبل جزر سليمان بالشنق",
    "People executed by the Solomon Islands": "أشخاص أعدموا من قبل جزر سليمان",
    "People executed by the Song dynasty by decapitation": "أشخاص أعدموا من قبل سلالة سونغ الحاكمة بقطع الرأس",
    "People executed by the Song dynasty": "أشخاص أعدموا من قبل سلالة سونغ الحاكمة",
    "People executed by the Soviet Union by ethnicity": "أشخاص أعدموا من قبل الاتحاد السوفيتي حسب المجموعة العرقية",
    "People executed by the Soviet Union by firearm": "أشخاص أعدموا من قبل الاتحاد السوفيتي بسلاح ناري",
    "People executed by the Soviet Union by firing squad": "أشخاص أعدموا من قبل الاتحاد السوفيتي رميا بالرصاص",
    "People executed by the Soviet Union by hanging": "أشخاص أعدموا من قبل الاتحاد السوفيتي بالشنق",
    "People executed by the Soviet Union by nationality": "أشخاص أعدموا من قبل الاتحاد السوفيتي حسب الجنسية",
    "People executed by the Soviet Union by religion": "أشخاص أعدموا من قبل الاتحاد السوفيتي حسب الدين",
    "People executed by the Soviet Union": "أشخاص أعدموا من قبل الاتحاد السوفيتي",
    "People executed by the Sui dynasty by decapitation": "أشخاص أعدموا من قبل مملكة سوي بقطع الرأس",
    "People executed by the Sui dynasty": "أشخاص أعدموا من قبل مملكة سوي",
    "People executed by the Swedish Empire": "أشخاص أعدموا من قبل الإمبراطورية السويدية",
    "People executed by the Tang dynasty by decapitation": "أشخاص أعدموا من قبل سلالة تانغ الحاكمة بقطع الرأس",
    "People executed by the Tang dynasty": "أشخاص أعدموا من قبل سلالة تانغ الحاكمة",
    "People executed by the Thirteen Colonies by firing squad": "أشخاص أعدموا من قبل المستعمرات الثلاث عشرة رميا بالرصاص",
    "People executed by the Thirteen Colonies by hanging": "أشخاص أعدموا من قبل المستعمرات الثلاث عشرة بالشنق",
    "People executed by the Thirteen Colonies": "أشخاص أعدموا من قبل المستعمرات الثلاث عشرة",
    "People executed by the Tsardom of Russia": "أشخاص أعدموا من قبل روسيا القيصرية",
    "People executed by the Umayyad Caliphate": "أشخاص أعدموا من قبل الدولة الأموية",
    "People executed by the United Kingdom by burning": "أشخاص أعدموا من قبل المملكة المتحدة بالحرق",
    "People executed by the United Kingdom by decapitation": "أشخاص أعدموا من قبل المملكة المتحدة بقطع الرأس",
    "People executed by the United Kingdom by firearm": "أشخاص أعدموا من قبل المملكة المتحدة بسلاح ناري",
    "People executed by the United Kingdom by firing squad": "أشخاص أعدموا من قبل المملكة المتحدة رميا بالرصاص",
    "People executed by the United Kingdom by hanging": "أشخاص أعدموا من قبل المملكة المتحدة بالشنق",
    "People executed by the United Kingdom": "أشخاص أعدموا من قبل المملكة المتحدة",
    "People executed by the United States by firearm": "أشخاص أعدموا من قبل الولايات المتحدة بسلاح ناري",
    "People executed by the United States by firing squad": "أشخاص أعدموا من قبل الولايات المتحدة رميا بالرصاص",
    "People executed by the United States by hanging": "أشخاص أعدموا من قبل الولايات المتحدة بالشنق",
    "People executed by the United States": "أشخاص أعدموا من قبل الولايات المتحدة",
    "People executed by the Weimar Republic by guillotine": "أشخاص أعدموا من قبل جمهورية فايمار بالمقصلة",
    "People executed by the Weimar Republic": "أشخاص أعدموا من قبل جمهورية فايمار",
    "People executed by the Yuan dynasty by decapitation": "أشخاص أعدموا من قبل مملكة يوان بقطع الرأس",
    "People executed by the Yuan dynasty": "أشخاص أعدموا من قبل مملكة يوان",
    "People executed by Trinidad and Tobago by hanging": "أشخاص أعدموا من قبل ترينيداد وتوباغو بالشنق",
    "People executed by Trinidad and Tobago": "أشخاص أعدموا من قبل ترينيداد وتوباغو",
    "People executed by Tunisia by decapitation": "أشخاص أعدموا من قبل تونس بقطع الرأس",
    "People executed by Tunisia by hanging": "أشخاص أعدموا من قبل تونس بالشنق",
    "People executed by Tunisia": "أشخاص أعدموا من قبل تونس",
    "People executed by Turkey by firearm": "أشخاص أعدموا من قبل تركيا بسلاح ناري",
    "People executed by Turkey by firing squad": "أشخاص أعدموا من قبل تركيا رميا بالرصاص",
    "People executed by Turkey by hanging": "أشخاص أعدموا من قبل تركيا بالشنق",
    "People executed by Turkey": "أشخاص أعدموا من قبل تركيا",
    "People executed by Uganda by burning": "أشخاص أعدموا من قبل أوغندا بالحرق",
    "People executed by Uganda by decapitation": "أشخاص أعدموا من قبل أوغندا بقطع الرأس",
    "People executed by Uganda": "أشخاص أعدموا من قبل أوغندا",
    "People executed by Ukraine by firearm": "أشخاص أعدموا من قبل أوكرانيا بسلاح ناري",
    "People executed by Ukraine by firing squad": "أشخاص أعدموا من قبل أوكرانيا رميا بالرصاص",
    "People executed by Ukraine": "أشخاص أعدموا من قبل أوكرانيا",
    "People executed by United States by hanging": "أشخاص أعدموا من قبل الولايات المتحدة بالشنق",
    "People executed by Upper Canada": "أشخاص أعدموا من قبل كندا العليا",
    "People executed by Utah by firing squad": "أشخاص أعدموا من قبل يوتا رميا بالرصاص",
    "People executed by Utah by hanging": "أشخاص أعدموا من قبل يوتا بالشنق",
    "People executed by Utah": "أشخاص أعدموا من قبل يوتا",
    "People executed by Venezuela by firing squad": "أشخاص أعدموا من قبل فنزويلا رميا بالرصاص",
    "People executed by Venezuela": "أشخاص أعدموا من قبل فنزويلا",
    "People executed by Vermont by hanging": "أشخاص أعدموا من قبل فيرمونت بالشنق",
    "People executed by Vermont": "أشخاص أعدموا من قبل فيرمونت",
    "People executed by Vichy France": "أشخاص أعدموا من قبل فرنسا الفيشية",
    "People executed by Vietnam by decapitation": "أشخاص أعدموا من قبل فيتنام بقطع الرأس",
    "People executed by Vietnam by firearm": "أشخاص أعدموا من قبل فيتنام بسلاح ناري",
    "People executed by Vietnam by firing squad": "أشخاص أعدموا من قبل فيتنام رميا بالرصاص",
    "People executed by Vietnam by guillotine": "أشخاص أعدموا من قبل فيتنام بالمقصلة",
    "People executed by Vietnam": "أشخاص أعدموا من قبل فيتنام",
    "People executed by Virginia by firing squad": "أشخاص أعدموا من قبل فرجينيا رميا بالرصاص",
    "People executed by Virginia by hanging": "أشخاص أعدموا من قبل فرجينيا بالشنق",
    "People executed by Virginia": "أشخاص أعدموا من قبل فرجينيا",
    "People executed by Wales by burning": "أشخاص أعدموا من قبل ويلز بالحرق",
    "People executed by Wales": "أشخاص أعدموا من قبل ويلز",
    "People executed by Wallachia by decapitation": "أشخاص أعدموا من قبل الأفلاق بقطع الرأس",
    "People executed by Wallachia": "أشخاص أعدموا من قبل الأفلاق",
    "People executed by Washington (state) by hanging": "أشخاص أعدموا من قبل ولاية واشنطن بالشنق",
    "People executed by Washington (state)": "أشخاص أعدموا من قبل ولاية واشنطن",
    "People executed by West Virginia by hanging": "أشخاص أعدموا من قبل فرجينيا الغربية بالشنق",
    "People executed by West Virginia": "أشخاص أعدموا من قبل فرجينيا الغربية",
    "People executed by Western Australia": "أشخاص أعدموا من قبل أستراليا الغربية",
    "People executed by Wisconsin by hanging": "أشخاص أعدموا من قبل ويسكونسن بالشنق",
    "People executed by Wisconsin": "أشخاص أعدموا من قبل ويسكونسن",
    "People executed by Wyoming by hanging": "أشخاص أعدموا من قبل وايومنغ بالشنق",
    "People executed by Wyoming": "أشخاص أعدموا من قبل وايومنغ",
    "People executed by Yemen by decapitation": "أشخاص أعدموا من قبل اليمن بقطع الرأس",
    "People executed by Yemen by firing squad": "أشخاص أعدموا من قبل اليمن رميا بالرصاص",
    "People executed by Yemen": "أشخاص أعدموا من قبل اليمن",
    "People executed by Yugoslavia by firing squad": "أشخاص أعدموا من قبل يوغسلافيا رميا بالرصاص",
    "People executed by Yugoslavia by hanging": "أشخاص أعدموا من قبل يوغسلافيا بالشنق",
    "People executed by Yugoslavia": "أشخاص أعدموا من قبل يوغسلافيا",
    "People executed by Zimbabwe by hanging": "أشخاص أعدموا من قبل زيمبابوي بالشنق",
    "People executed by Zimbabwe": "أشخاص أعدموا من قبل زيمبابوي",
    "People executed in British North America by hanging": "أشخاص أعدموا في أمريكا الشمالية البريطانية بالشنق",
    "People executed in Charles Town, West Virginia": "أشخاص أعدموا في تشارلز تاون",
    "People executed in the Holy Roman Empire by burning": "أشخاص أعدموا في الإمبراطورية الرومانية المقدسة بالحرق",
    "People executed in the Holy Roman Empire by decapitation": "أشخاص أعدموا في الإمبراطورية الرومانية المقدسة بقطع الرأس",
    "People executed in the Philippines during World War II": "أشخاص أعدموا في الفلبين خلال الحرب العالمية الثانية",
    "People executed in the Salem witch trials": "أشخاص أعدموا في محاكمات السحر في سالم",
    "People executed the Netherlands by guillotine": "أشخاص أعدموا هولندا بالمقصلة",
    "People from Baden-Württemberg executed by Nazi Germany": "أشخاص من بادن-فورتمبيرغ أعدموا من قبل ألمانيا النازية",
    "People from Bavaria executed by Nazi Germany": "أشخاص من بافاريا أعدموا من قبل ألمانيا النازية",
    "People from Berlin executed by Nazi Germany": "أشخاص من برلين أعدموا من قبل ألمانيا النازية",
    "People from Brandenburg executed by Nazi Germany": "أشخاص من براندنبورغ أعدموا من قبل ألمانيا النازية",
    "People from Bremen (state) executed by Nazi Germany": "أشخاص من ولاية بريمن أعدموا من قبل ألمانيا النازية",
    "People from Georgia (country) executed by the Soviet Union": "أشخاص من جورجيا أعدموا من قبل الاتحاد السوفيتي",
    "People from Hamburg executed by Nazi Germany": "أشخاص من هامبورغ أعدموا من قبل ألمانيا النازية",
    "People from Hesse executed by Nazi Germany": "أشخاص من هسن أعدموا من قبل ألمانيا النازية",
    "People from Lower Saxony executed by Nazi Germany": "أشخاص من سكسونيا السفلى أعدموا من قبل ألمانيا النازية",
    "People from Mecklenburg-Vorpommern executed by Nazi Germany": "أشخاص من مكلنبورغ فوربومرن أعدموا من قبل ألمانيا النازية",
    "People from North Rhine-Westphalia executed by Nazi Germany": "أشخاص من شمال الراين-وستفاليا أعدموا من قبل ألمانيا النازية",
    "People from Rhineland-Palatinate executed by Nazi Germany": "أشخاص من راينلند بالاتينات أعدموا من قبل ألمانيا النازية",
    "People from Saxony executed by Nazi Germany": "أشخاص من ساكسونيا أعدموا من قبل ألمانيا النازية",
    "People from Saxony-Anhalt executed by Nazi Germany": "أشخاص من ساكسونيا أنهالت أعدموا من قبل ألمانيا النازية",
    "People from Schleswig-Holstein executed by Nazi Germany": "أشخاص من شليسفيغ هولشتاين أعدموا من قبل ألمانيا النازية",
    "People from Thuringia executed by Nazi Germany": "أشخاص من تورينغن أعدموا من قبل ألمانيا النازية",
    "Polish people executed abroad": "بولنديون أعدموا في الخارج",
    "Polish people executed by Nazi Germany": "بولنديون أعدموا من قبل ألمانيا النازية",
    "Polish people executed by the Russian Empire": "بولنديون أعدموا من قبل الإمبراطورية الروسية",
    "Polish people executed by the Soviet Union": "بولنديون أعدموا من قبل الاتحاد السوفيتي",
    "Portuguese people executed abroad": "برتغاليون أعدموا في الخارج",
    "Roman Catholic priests executed by Nazi Germany": "كهنة كاثوليك رومان أعدموا من قبل ألمانيا النازية",
    "Romanian people executed abroad": "رومان أعدموا في الخارج",
    "Romanian people executed by Nazi Germany": "رومان أعدموا من قبل ألمانيا النازية",
    "Russian people executed abroad": "روس أعدموا في الخارج",
    "Russian people executed by Nazi Germany": "روس أعدموا من قبل ألمانيا النازية",
    "Russian people executed by Russia": "روس أعدموا من قبل روسيا",
    "Russian people executed by the Soviet Union": "روس أعدموا من قبل الاتحاد السوفيتي",
    "Serbian people executed by Nazi Germany": "صرب أعدموا من قبل ألمانيا النازية",
    "Singaporean people executed abroad": "سنغافوريون أعدموا في الخارج",
    "Slovak people executed by Nazi Germany": "سلوفاكيون أعدموا من قبل ألمانيا النازية",
    "Slovenian people executed by Nazi Germany": "سلوفينيون أعدموا من قبل ألمانيا النازية",
    "Somalian people executed abroad": "صوماليون أعدموا في الخارج",
    "South African people executed abroad": "جنوب إفريقيون أعدموا في الخارج",
    "Soviet people executed abroad": "سوفيت أعدموا في الخارج",
    "Spanish people executed abroad": "إسبان أعدموا في الخارج",
    "Spanish people executed by Nazi Germany": "إسبان أعدموا من قبل ألمانيا النازية",
    "Swedish people executed abroad": "سويديون أعدموا في الخارج",
    "Swiss people executed abroad": "سويسريون أعدموا في الخارج",
    "Swiss people executed by Nazi Germany": "سويسريون أعدموا من قبل ألمانيا النازية",
    "Syrian people executed abroad": "سوريون أعدموا في الخارج",
    "Tajikistani people executed by the Soviet Union": "طاجيك أعدموا من قبل الاتحاد السوفيتي",
    "Thai people executed abroad": "تايلنديون أعدموا في الخارج",
    "Tunisian people executed abroad": "تونسيون أعدموا في الخارج",
    "Turkmenistan people executed by the Soviet Union": "تركمانيون أعدموا من قبل الاتحاد السوفيتي",
    "Ukrainian people executed abroad": "أوكرانيون أعدموا في الخارج",
    "Ukrainian people executed by Nazi Germany": "أوكرانيون أعدموا من قبل ألمانيا النازية",
    "Ukrainian people executed by the Russian Empire": "أوكرانيون أعدموا من قبل الإمبراطورية الروسية",
    "Ukrainian people executed by the Soviet Union": "أوكرانيون أعدموا من قبل الاتحاد السوفيتي",
    "Uzbekistani people executed by the Soviet Union": "أوزبكستانيون أعدموا من قبل الاتحاد السوفيتي",
    "Yugoslav people executed abroad": "يوغسلافيون أعدموا في الخارج",
    "Yugoslav people executed by Nazi Germany": "يوغسلافيون أعدموا من قبل ألمانيا النازية",
    "Yugoslav people executed by the Soviet Union": "يوغسلافيون أعدموا من قبل الاتحاد السوفيتي",
}

data_4 = {
    "Yugoslav people executed in Nazi concentration camps": "يوغسلافيون أعدموا في معسكرات الاعتقال النازية",
    "Norwegian people executed in Nazi concentration camps": "نرويجيون أعدموا في معسكرات الاعتقال النازية",
    "Mauritian people executed in Nazi concentration camps": "موريشيوسيون أعدموا في معسكرات الاعتقال النازية",
    "People executed in Nazi concentration camps": "أشخاص أعدموا في معسكرات الاعتقال النازية",
    "Ukrainian people executed in Nazi concentration camps": "أوكرانيون أعدموا في معسكرات الاعتقال النازية",
    "French people executed in Nazi concentration camps": "فرنسيون أعدموا في معسكرات الاعتقال النازية",
    "Polish people executed in Nazi concentration camps": "بولنديون أعدموا في معسكرات الاعتقال النازية",
    "Serbian people executed in Nazi concentration camps": "صرب أعدموا في معسكرات الاعتقال النازية",
    "German people executed in Nazi concentration camps": "ألمان أعدموا في معسكرات الاعتقال النازية",
    "Hungarian people executed in Nazi concentration camps": "مجريون أعدموا في معسكرات الاعتقال النازية",
    "Croatian people executed in Nazi concentration camps": "كروات أعدموا في معسكرات الاعتقال النازية",
    "Czech people executed in Nazi concentration camps": "تشيكيون أعدموا في معسكرات الاعتقال النازية",
    "British people executed in Nazi concentration camps": "بريطانيون أعدموا في معسكرات الاعتقال النازية",
    "Bulgarian people executed in Nazi concentration camps": "بلغاريون أعدموا في معسكرات الاعتقال النازية",
    "Canadian people executed in Nazi concentration camps": "كنديون أعدموا في معسكرات الاعتقال النازية",
    "American people executed in Nazi concentration camps": "أمريكيون أعدموا في معسكرات الاعتقال النازية",
    "Argentine people executed in Nazi concentration camps": "أرجنتينيون أعدموا في معسكرات الاعتقال النازية",
    "Austrian people executed in Nazi concentration camps": "نمساويون أعدموا في معسكرات الاعتقال النازية",
    "Belgian people executed in Nazi concentration camps": "بلجيكيون أعدموا في معسكرات الاعتقال النازية",
    "Dutch people executed in Nazi concentration camps": "هولنديون أعدموا في معسكرات الاعتقال النازية",
}

data_5 = {
    "American people executed for murder": "أمريكيون أعدموا بتهمة قتل",
    "American people executed for rape": "أمريكيون أعدموا بتهمة الاغتصاب",
    "American people executed for war crimes": "أمريكيون أعدموا بتهمة جرائم حرب",
    "American people executed for witchcraft": "أمريكيون أعدموا بتهمة السحر",
    "American police officers executed for murder": "ضباط شرطة أمريكيون أعدموا بتهمة قتل",
    "Australian people executed for murder": "أستراليون أعدموا بتهمة قتل",
    "Austrian Nazis executed for war crimes": "نازيون نمساويون أعدموا بتهمة جرائم حرب",
    "Austrian people executed for war crimes": "نمساويون أعدموا بتهمة جرائم حرب",
    "Austrian people executed for witchcraft": "نمساويون أعدموا بتهمة السحر",
    "British people executed for murder": "بريطانيون أعدموا بتهمة قتل",
    "Chinese people executed for witchcraft": "صينيون أعدموا بتهمة السحر",
    "Christians executed for refusing to convert to Islam": "مسيحيون أعدموا بتهمة رفض اعتناق الإسلام",
    "Danish people executed for witchcraft": "دنماركيون أعدموا بتهمة السحر",
    "Dutch people executed for witchcraft": "هولنديون أعدموا بتهمة السحر",
    "English people executed for witchcraft": "إنجليز أعدموا بتهمة السحر",
    "Finnish people executed for witchcraft": "فنلنديون أعدموا بتهمة السحر",
    "French people executed for murder": "فرنسيون أعدموا بتهمة قتل",
    "French people executed for war crimes": "فرنسيون أعدموا بتهمة جرائم حرب",
    "French people executed for witchcraft": "فرنسيون أعدموا بتهمة السحر",
    "German people executed for murder": "ألمان أعدموا بتهمة قتل",
    "German people executed for war crimes": "ألمان أعدموا بتهمة جرائم حرب",
    "German people executed for witchcraft": "ألمان أعدموا بتهمة السحر",
    "Hungarian people executed for war crimes": "مجريون أعدموا بتهمة جرائم حرب",
    "Icelandic people executed for witchcraft": "آيسلنديون أعدموا بتهمة السحر",
    "Iranian people executed for murder": "إيرانيون أعدموا بتهمة قتل",
    "Italian people executed for war crimes": "إيطاليون أعدموا بتهمة جرائم حرب",
    "Italian people executed for witchcraft": "إيطاليون أعدموا بتهمة السحر",
    "Japanese people executed for murder": "يابانيون أعدموا بتهمة قتل",
    "Japanese people executed for war crimes": "يابانيون أعدموا بتهمة جرائم حرب",
    "Nazis executed for war crimes": "نازيون أعدموا بتهمة جرائم حرب",
    "Norwegian people executed for witchcraft": "نرويجيون أعدموا بتهمة السحر",
    "People executed for attempted murder": "أشخاص أعدموا بتهمة الشروع في القتل",
    "People executed for blasphemy": "أشخاص أعدموا بتهمة ازدراء الدين",
    "People executed for crimes against humanity": "أشخاص أعدموا بتهمة جرائم ضد الإنسانية",
    "People executed for murder": "أشخاص أعدموا بتهمة قتل",
    "People executed for rape": "أشخاص أعدموا بتهمة الاغتصاب",
    "People executed for refusing to convert to Christianity": "أشخاص أعدموا بتهمة رفض اعتناق المسيحية",
    "People executed for refusing to convert to Islam": "أشخاص أعدموا بتهمة رفض اعتناق الإسلام",
    "People executed for robbery": "أشخاص أعدموا بتهمة السرقة",
    "People executed for sex crimes": "أشخاص أعدموا بتهمة الجرائم الجنسية",
    "People executed for treason against Argentina": "أشخاص أعدموا بتهمة الخيانة العظمى ضد الأرجنتين",
    "People executed for treason against Austria": "أشخاص أعدموا بتهمة الخيانة العظمى ضد النمسا",
    "People executed for treason against Austria-Hungary": "أشخاص أعدموا بتهمة الخيانة العظمى ضد الإمبراطورية النمساوية المجرية",
    "People executed for treason against Bangladesh": "أشخاص أعدموا بتهمة الخيانة العظمى ضد بنغلاديش",
    "People executed for treason against Cambodia": "أشخاص أعدموا بتهمة الخيانة العظمى ضد كمبوديا",
    "People executed for treason against Canada": "أشخاص أعدموا بتهمة الخيانة العظمى ضد كندا",
    "People executed for treason against China": "أشخاص أعدموا بتهمة الخيانة العظمى ضد الصين",
    "People executed for treason against Cuba": "أشخاص أعدموا بتهمة الخيانة العظمى ضد كوبا",
    "People executed for treason against Czechoslovakia": "أشخاص أعدموا بتهمة الخيانة العظمى ضد تشيكوسلوفاكيا",
    "People executed for treason against East Germany": "أشخاص أعدموا بتهمة الخيانة العظمى ضد ألمانيا الشرقية",
    "People executed for treason against England": "أشخاص أعدموا بتهمة الخيانة العظمى ضد إنجلترا",
    "People executed for treason against Estonia": "أشخاص أعدموا بتهمة الخيانة العظمى ضد إستونيا",
    "People executed for treason against Finland": "أشخاص أعدموا بتهمة الخيانة العظمى ضد فنلندا",
    "People executed for treason against France": "أشخاص أعدموا بتهمة الخيانة العظمى ضد فرنسا",
    "People executed for treason against Germany": "أشخاص أعدموا بتهمة الخيانة العظمى ضد ألمانيا",
    "People executed for treason against Greece": "أشخاص أعدموا بتهمة الخيانة العظمى ضد اليونان",
    "People executed for treason against Guinea": "أشخاص أعدموا بتهمة الخيانة العظمى ضد غينيا",
    "People executed for treason against Hungary": "أشخاص أعدموا بتهمة الخيانة العظمى ضد المجر",
    "People executed for treason against Iran": "أشخاص أعدموا بتهمة الخيانة العظمى ضد إيران",
    "People executed for treason against Iraq": "أشخاص أعدموا بتهمة الخيانة العظمى ضد العراق",
    "People executed for treason against Ireland": "أشخاص أعدموا بتهمة الخيانة العظمى ضد أيرلندا",
    "People executed for treason against Israel": "أشخاص أعدموا بتهمة الخيانة العظمى ضد إسرائيل",
    "People executed for treason against Italy": "أشخاص أعدموا بتهمة الخيانة العظمى ضد إيطاليا",
    "People executed for treason against Japan": "أشخاص أعدموا بتهمة الخيانة العظمى ضد اليابان",
    "People executed for treason against Kenya": "أشخاص أعدموا بتهمة الخيانة العظمى ضد كينيا",
    "People executed for treason against Mexico": "أشخاص أعدموا بتهمة الخيانة العظمى ضد المكسيك",
    "People executed for treason against Nazi Germany": "أشخاص أعدموا بتهمة الخيانة العظمى ضد ألمانيا النازية",
    "People executed for treason against North Korea": "أشخاص أعدموا بتهمة الخيانة العظمى ضد كوريا الشمالية",
    "People executed for treason against Norway": "أشخاص أعدموا بتهمة الخيانة العظمى ضد النرويج",
    "People executed for treason against Pakistan": "أشخاص أعدموا بتهمة الخيانة العظمى ضد باكستان",
    "People executed for treason against Poland": "أشخاص أعدموا بتهمة الخيانة العظمى ضد بولندا",
    "People executed for treason against Russia": "أشخاص أعدموا بتهمة الخيانة العظمى ضد روسيا",
    "People executed for treason against Scotland": "أشخاص أعدموا بتهمة الخيانة العظمى ضد إسكتلندا",
    "People executed for treason against Senegal": "أشخاص أعدموا بتهمة الخيانة العظمى ضد السنغال",
    "People executed for treason against Serbia": "أشخاص أعدموا بتهمة الخيانة العظمى ضد صربيا",
    "People executed for treason against South Africa": "أشخاص أعدموا بتهمة الخيانة العظمى ضد جنوب إفريقيا",
    "People executed for treason against Spain": "أشخاص أعدموا بتهمة الخيانة العظمى ضد إسبانيا",
    "People executed for treason against Suriname": "أشخاص أعدموا بتهمة الخيانة العظمى ضد سورينام",
    "People executed for treason against Sweden": "أشخاص أعدموا بتهمة الخيانة العظمى ضد السويد",
    "People executed for treason against the Austrian Empire": "أشخاص أعدموا بتهمة الخيانة العظمى ضد الإمبراطورية النمساوية",
    "People executed for treason against the Confederate States of America": "أشخاص أعدموا بتهمة الخيانة العظمى ضد الولايات الكونفدرالية الأمريكية",
    "People executed for treason against the Democratic Republic of the Congo": "أشخاص أعدموا بتهمة الخيانة العظمى ضد جمهورية الكونغو الديمقراطية",
    "People executed for treason against the Netherlands": "أشخاص أعدموا بتهمة الخيانة العظمى ضد هولندا",
    "People executed for treason against the Ottoman Empire": "أشخاص أعدموا بتهمة الخيانة العظمى ضد الدولة العثمانية",
    "People executed for treason against the Republic of the Congo": "أشخاص أعدموا بتهمة الخيانة العظمى ضد جمهورية الكونغو",
    "People executed for treason against the Soviet Union": "أشخاص أعدموا بتهمة الخيانة العظمى ضد الاتحاد السوفيتي",
    "People executed for treason against the United Kingdom": "أشخاص أعدموا بتهمة الخيانة العظمى ضد المملكة المتحدة",
    "People executed for treason against the United States": "أشخاص أعدموا بتهمة الخيانة العظمى ضد الولايات المتحدة",
    "People executed for treason against Turkey": "أشخاص أعدموا بتهمة الخيانة العظمى ضد تركيا",
    "People executed for treason against Wallachia": "أشخاص أعدموا بتهمة الخيانة العظمى ضد الأفلاق",
    "People executed for treason against Yugoslavia": "أشخاص أعدموا بتهمة الخيانة العظمى ضد يوغسلافيا",
    "People executed for treason by country": "أشخاص أعدموا بتهمة خيانة حسب البلد",
    "People executed for treason": "أشخاص أعدموا بتهمة خيانة",
    "People executed for war crimes": "أشخاص أعدموا بتهمة جرائم حرب",
    "People executed for witchcraft": "أشخاص أعدموا بتهمة السحر",
    "People from the Spanish Netherlands executed for witchcraft": "أشخاص من هولندا الإسبانية أعدموا بتهمة السحر",
    "Police officers executed for crimes against humanity": "ضباط شرطة أعدموا بتهمة جرائم ضد الإنسانية",
    "Police officers executed for murder": "ضباط شرطة أعدموا بتهمة قتل",
    "Police officers executed for treason": "ضباط شرطة أعدموا بتهمة خيانة",
    "Polish people executed for witchcraft": "بولنديون أعدموا بتهمة السحر",
    "Russian people executed for war crimes": "روس أعدموا بتهمة جرائم حرب",
    "Scottish people executed for treason against the United Kingdom": "إسكتلنديون أعدموا بتهمة الخيانة العظمى ضد المملكة المتحدة",
    "Scottish people executed for witchcraft": "إسكتلنديون أعدموا بتهمة السحر",
    "South African people executed for murder": "جنوب إفريقيون أعدموا بتهمة قتل",
    "Spanish people executed for witchcraft": "إسبان أعدموا بتهمة السحر",
    "Swedish people executed for witchcraft": "سويديون أعدموا بتهمة السحر",
    "Swiss people executed for witchcraft": "سويسريون أعدموا بتهمة السحر",
}

data_6 = {
    "Executed artists": "فنانون أعدموا",
    "Executed assassins": "منفذو اغتيالات أعدموا",
    "Executed children": "أطفال أعدموا",
    "Executed communists": "شيوعيون أعدموا",
    "Executed philosophers": "فلاسفة أعدموا",
    "Executed police officers": "ضباط شرطة أعدموا",
    "Executed politicians": "سياسيون أعدموا",
    "Executed nobility": "نبلاء أعدموا",
    "Executed military leaders": "قادة عسكريون أعدموا",
    "Executed military personnel": "أفراد عسكريون أعدموا",
    "Executed monarchs": "ملكيون أعدموا",
    "Executed mass murderers": "قتلة جماعيون أعدموا",
    "Executed journalists": "صحفيون أعدموا",
    "Executed heads of government": "رؤساء حكومات أعدموا",
    "Executed presidents": "رؤساء أعدموا",
    "Executed priests": "كهنة أعدموا",
    "Executed revolutionaries": "ثوار أعدموا",
    "Executed Roman emperors": "أباطرة رومان أعدموا",
    "Executed scientists": "علماء أعدموا",
    "Executed activists": "ناشطون أعدموا",
    "Executed writers": "كتاب أعدموا",
    "Executed trade unionists": "نقابيون أعدموا",
    "Executed students": "طلاب أعدموا",
    "Executed spies": "جواسيس أعدموا",
    "Executed serial killers": "قتلة متسلسلون أعدموا",
    "Executed anarchists": "لاسلطويون أعدموا",
}

to_test = [
    ("test_executed_0", data_0),
    ("test_executed_1", data_1),
    ("test_executed_2", data_2),
    ("test_executed_3", data_3),
    ("test_executed_4", data_4),
    ("test_executed_5", data_5),
    ("test_executed_6", data_6),
]


@pytest.mark.parametrize("category, expected", data_0.items(), ids=data_0.keys())
def test_executed_0(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
def test_executed_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data_3.items(), ids=data_3.keys())
def test_executed_3(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)

    # dump_diff_text (expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""

Integration tests

TODO: write tests for the parameters:
        splitter: str = " ",
        sort_ar_labels: bool = False,
"""
import pytest

from ArWikiCats.translations_formats import FormatDataDouble


@pytest.fixture
def bot() -> FormatDataDouble:
    # Template data with both nationality and sport placeholders
    formatted_data = {
        "{film_key} films": "أفلام {film_ar}",
        "{film_key} television commercials": "إعلانات تجارية تلفزيونية {film_ar}",
    }

    # film_keys_for_female
    data_list2 = {
        "action comedy": "حركة كوميدية",
        "action thriller": "إثارة حركة",
        "action": "حركة",
        "drama": "درامية",
        "upcoming": "قادمة",
        "horror": "رعب",
        "black": "سوداء",
        "black-and-white": "أبيض وأسود",
        "psychological horror": "رعب نفسي",
    }

    # Create an instance of the FormatDataDouble class with the formatted data and data list
    _bot = FormatDataDouble(
        formatted_data=formatted_data,
        data_list=data_list2,
        key_placeholder="{film_key}",
        value_placeholder="{film_ar}",
    )

    put_label_last = {
        "low-budget",
        "christmas",
        "lgbtq-related",
        "upcoming",
    }
    _bot.update_put_label_last(put_label_last)
    return _bot


test_data = {
    "black-and-white films": "أفلام أبيض وأسود",
    "black-and-white action films": "أفلام أبيض وأسود حركة",
    "drama action television commercials": "إعلانات تجارية تلفزيونية درامية حركة",
    "horror upcoming films": "أفلام رعب قادمة",
    "psychological horror films": "أفلام رعب نفسي",
    "psychological horror black-and-white films": "أفلام رعب نفسي أبيض وأسود",
    "horror horror films": "أفلام رعب رعب",
}


@pytest.mark.parametrize("category,expected", test_data.items(), ids=test_data.keys())
def test_year_country_combinations(bot: FormatDataDouble, category: str, expected: str) -> None:
    """
    Test
    """
    result = bot.search(category)
    assert result == expected


test_match_key_data = {
    "Yemeni action films": "action",
    "Yemeni action drama films": "action drama",
    "Yemeni upcoming horror films": "upcoming horror",
    "Yemeni black-and-white films": "black-and-white",
    "psychological horror black-and-white films": "psychological horror black-and-white",
}


@pytest.mark.parametrize("category, expected", test_match_key_data.items(), ids=test_match_key_data.keys())
@pytest.mark.fast
def test_match_key(bot: FormatDataDouble, category: str, expected: str) -> None:
    result = bot.match_key(category)
    assert result == expected



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "middle eastern traditional music": "موسيقى تقليدية شرق أوسطي",
    "korean traditional music": "موسيقى تقليدية كوري",
    "Christian rock songs": "تصنيف:أغاني روك مسيحي",
    "danish dance songs": "تصنيف:أغاني رقص دنماركي",
    "hong kong rock songs": "تصنيف:أغاني روك هونغ كونغي",
    "irish pop songs": "تصنيف:أغاني بوب أيرلندي",
    "taiwanese hip hop": "تصنيف:هيب هوب تايواني",
    "australian electronic dance music": "",
    "austrian rock": "تصنيف:روك نمساوي",
    "english country music": "تصنيف:كانتري إنجليزي",
    "Category:Bengali folk songs": "تصنيف:أغاني فولك بنغالي",
    "Category:Indian folk songs": "تصنيف:أغاني فولك هندي",
    "Category:American rock music": "تصنيف:موسيقى الروك أمريكي",
    "Category:Danish country music": "تصنيف:كانتري دنماركي",
    "Category:Estonian rock music": "تصنيف:موسيقى الروك إستوني",
    "Category:French electronic songs": "تصنيف:أغاني إليكترونيك فرنسي",
    "Category:Mongolian traditional music": "تصنيف:موسيقى تقليدية منغولي",
    "Category:Serbian hip-hop": "تصنيف:هيب هوب صربي",
    "Christian country music": "تصنيف:كانتري مسيحي",
    "Christian electronic dance music songs": "تصنيف:أغاني موسيقى الرقص الإلكترونية مسيحي",
    "Christian electronic dance music": "تصنيف:موسيقى الرقص الإلكترونية مسيحي",
    "Christian hip-hop songs": "تصنيف:أغاني هيب هوب مسيحي",
    "Christian hip-hop": "تصنيف:هيب هوب مسيحي",
    "Christian R&B": "تصنيف:ريذم أند بلوز مسيحي",
    "Jewish dance": "تصنيف:رقص يهودي",
    "Jewish folk songs": "تصنيف:أغاني فولك يهودي",
    "Jewish hip-hop": "تصنيف:هيب هوب يهودي",
    "Jewish rock songs": "تصنيف:أغاني روك يهودي",
    "Jewish rock": "تصنيف:روك يهودي",
}

to_test = [
    ("test_songs_1", data1),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.skip2
def test_songs_1(category: str, expected: str) -> None:
    """
    Run a single assertion that resolving the Arabic category label for `category` matches `expected`.

    Parameters:
        category (str): English category string to resolve.
        expected (str): Expected Arabic label for `category`.

    """
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.skip2
def test_peoples(name: str, data: dict[str, str]) -> None:
    """
    Run a dumped comparison of resolved Arabic labels for a dataset and assert there are no differences.

    Parameters:
        name (str): Identifier used when writing the diff output.
        data (dict[str, str]): Mapping from English category strings to expected Arabic label strings.

    Raises:
        AssertionError: If the computed diff does not match the expected result.
    """
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
